* migstat09_spss.zip: migstat09.sps .


* IBM SPSS Statistics 20, Release 20.0.0.1 .

set length none.
set width 132.
set header no.


* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp .
CD '<Arbeitsverzeichnis>'.

* =====================================================================.
* Programmname: migstat09.sps                                          .
*    SPSS-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM             .
*    MIKROZENSUS 2009                                                  .
*                                                                      .
* Programmautor/en:                                                    .
* SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt,     .
*            Referat F 204 Migration und integration, Wohnen)          .
* Anpassungen an Scientific Use File Mikrozensus 2009: Delia Jaeger,   .
*            Bernhard Schimpl-Neimanns (GESIS, GML)                    .
*                                                                      .
* Programmzweck:                                                       .
* Dieses Programm dient der Replikation des Migrationsstatus, Variable .
* EF2001, und der Staatsangehoerigkeit zum Migrationsstatus (EF2008)   .
* im Scientific Use File (SUF) des Mikrozensus 2009.                   .
* Die Programme basieren auf den SAS-Programmen zum Original-          .
* Mikrozensus des Statistischen Bundesamtes und wurden an Recodierungen.
* des SUF angepasst.                                                   .
* Bei der Replikation der Variablen Staatsangehoerigkeit zum           .
* Migrationsstatus (MIGS und MIGS2009) ist zu beachten, dass aus       .
* Gruenden des Datenschutzes Angaben zur zweiten Staatsangehoerigkeit  .
* (EF354, EF362, EF370) nur rudimentaer vorhanden sind. Des Weiteren   .
* sind die zur Konstruktion von MIGS verwendeten Variablen             .
*    EF369 1. Staatsangehoerigkeit (der Person),                       .
*    EF353 1. ausl. Staatsangehoerigk.: Mutter und                     .
*    EF362 1. ausl. Staatsangehoerigk.:Vater                           .
* unterschiedlich codiert. Die Replikation ist deshalb nur mit         .
* Abweichungen moeglich. Da die Variable EF2008 im SUF enthalten ist,  .
* wird keine Harmonisierung der Ausgangsvariablen EF369, EF353 und     .
* EF362 vorgenommen.                                                   .
*                                                                      .
* Weiterfuehrende Programmbeschreibung:                                .
*  Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des        .
*   Migrationshintergrundes in den Mikrozensus Scientific-Use-Files    .
*   2005-2009. GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS.    .
*   URL: http://www.gesis.org/fileadmin/upload/forschung/              .
*        publikationen/gesis_reihen/gesis_methodenberichte/2012/       .
*        TechnicalReport_2012-08.pdf                                   .
*                                                                      .
* Download dieser Datei:                                               .
*   http://www.gesis.org/missy/studie/klassifikationen/                .
*   konzepte-und-definitionen/migrationshintergrund/migstat09_spss.zip .
*                                                                      .
* Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf        .
*   dem Weg zu einer definitorischen Abgrenzung - S. 398-407 in:       .
* Statistisches Bundesamt, 2011: Bevoelkerung mit Migrationshintergrund.
*   Ergebnisse des Mikrozensus 2009. Fachserie 1 Reihe 2.2. Wiesbaden  .
* URL: https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/.
*  MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob= .
*   publicationFile; letzter Zugriff: 24.07.2012                       .
*                                                                      .
* Programmstruktur:                                                    .
* 0. Datenvorbereitung                                                 .
* 1. Grundtypisierung des Migationshintergrundes                       .
* 2. Identifikation von 3-Generationen-Haushalten                      .
* 3. Endtypisierung der Grosseltern                                    .
* 4. Endtypisierung der Eltern                                         .
* 5. Endtypisierung Befragte                                           .
* 6. Umsetzung von Zeitreihenkompatibilitaet                           .
* 7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse           .
*                                                                      .
* Programmstatus:                                                      .
*   Getestet mit IBM SPSS Statistics 20, Release 20.0.0.1, und dem     .
*   Scientific Use File Mikrozensus 2009                               .
*   Stand: Juli 2012.                                                  .
*                                                                      .
* =====================================================================.

* Variablenauswahl Scientific Use File Mikrozensus 2009 .
*    Lokalen Dateinamen inkl. Verzeichnis in <> eintragen .
get file = '<mz2009>' 
   /keep = EF1   EF3   EF4   EF5a  EF5b  EF8   EF9   EF12  EF30  EF31 
           EF37  EF44  EF46  EF47  EF49  EF50  EF51  EF52  EF53  EF54  EF55 
           EF349 EF350 EF351 EF352 EF353 EF354 EF355 EF356 EF382
           EF357 EF358 EF359 EF360 EF361 EF362 EF363 EF364 EF365  
           EF366 EF367 EF368 EF369 EF370 EF371 EF372 EF373 EF374 
           EF663 EF952 EF2001 to EF2011.

missing values all().

* ====================================================================.
* 0. DATENVORBEREITUNG .

* Satznummer im Ausgangsfile sichern.
compute ID = $casenum.
var lab ID "Satznummer Ausgangsfile".
formats ID (f6.0).

* Neue Haushaltsnr. (V4) bilden, um extra Programme fuer Jahresbestand .
*      (EF5B=0) und Jahresueberhang (EF5b=1) zu vermeiden.
compute V4 = EF4 * 100 + EF5b * 10 + EF12.
var label V4 'HHNR EF4 * 100 + EF5b*10 + EF12'.
formats V4 (f4.0).

* Neue PERS.Nr.
compute V5 = EF5a.
var label V5 'PERS.NR im HH (ex EF5a)'.
formats V5 (f2.0).

* ============================================================================.
* Datenkorrekturen (X) der Mutter-Kind-Beziehungen                            .
*   siehe 2. Identifikation 3-Gen-HH                                          .
*   EF3 EF4   V4 EF5a EF5b EF12 V5 EF44 EF46 EF52 EF53 MUTTER gmnr max_gmnr   .
*  2637  12 1202   1    0    2   1  34    2    1 X  2     1     2      2      .
*  2637  12 1202   2    0    2   2   0    2    1    1     1     1      2      .
*                                                                             .
* 11354  20 2002   1    0    2   1  24    2    1 X  2     1     2      2      .
* 11354  20 2002   2    0    2   2   4    2    1    1     1     1      2      .
*                                                                             .
* 25858   7  704   1    0    4   1  33    2    1 X  2     1     2      2      .
* 25858   7  704   2    0    4   2   6    2    1    1     1     1      2      .
* Originalvariablen sichern.
compute EF52_O = EF52.
compute EF53_O = EF53.
do if (EF3=2637 & EF4=12 & EF5b=0 & EF12=2 & EF5a=1).
      recode EF52 (1=8). 
      recode EF53 (2=-5).
end if.

do if (EF3=11354 & EF4=20 & EF5b=0 & EF12=2 & EF5a=1).
      recode EF52 (1=8). 
      recode EF53 (2=-5).
end if.

do if (EF3=25858 & EF4=7 & EF5b=0 & EF12=4 & EF5a=1).
      recode EF52 (1=8). 
      recode EF53 (2=-5).
end if.
execute.

* ============================================================================.

sort cases by EF1  /* Bundesland */
              EF3  /* Auswahlbezirk */
              V4   /* fortlfd. HH-Nr. inkl. Jahresueberhang */
              V5.  /* neue Pers.nr. im HH */
execute.

* ====================================================================.
* 1. Grundtypisierung des Migrationshintergrundes                     .
*       Es werden zunaechst nur die Angaben der Person selbst zur     .
*       Typisierung verwendet. Die erste Typisierung erfolgt nach     .
*       Angaben zur Staatsangehoerigkeit (deutsch / nicht-deutsch)    . 
*       und Geburtsland (Ausland / Inland).                           .
*       Zur Unterscheidung der Gruppe eingebuergerter Zuwanderer      .
*       (MIG=31) nach einem evtl. Status als Spaetaussiedler wird     .
*       abschliessend geprueft ob der Ehegatte, der Vater oder die    . 
*       Mutter im Haushalt einen Spaetaussiedlerstatus besitzt.       . 
*       Trifft dies zu, erfolgt eine Rekodierung (Plausibilisierung)  .
*       von MIG=31 'zugewanderter eingebuergerter Auslaender'         .
*       zu  MIG=22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers      .
*                   (mit/ohne Einbuerg)'.                             .
*                                                                     .
* Die Original-Zuweisungen von Variablen zur zweiten Staatsangehoe-   .
* rigkeit (EF354, EF362, EF370) werden aufgrund nicht vergleichbarer  .
* Codierungen im Folgenden deaktiviert.                               .

compute Gebj=EF47.
var label Gebj 'Geburtsjahr (EF47)'.
formats Gebj (f4.0).

compute BRDBorn=EF366.
var label BRDBorn 'Geburtsland: BRD (EF366)'.
formats BRDBorn (f1.0).
val label BRDBorn 1 'Ja, hier geboren' 
                  8 'Nein, zugezogen' 
                  9 'ohne Angabe'.

recode BRDBorn (1=0) (8=1) (9=9) (else=9) into Zuzug.
var label Zuzug 'Zuzug ex BRDBorn, EF366'.
formats Zuzug (f1.0).
value label Zuzug 0 'kein Zuzug' 
                  1 'foreign born' 
                  2 'Zuzug nach 6+ Mo im Ausland:= in D geboren' 
                  9 'k.A.'.

compute JZuzug=EF367.
if (EF367=1949) JZuzug=1949. /* Zuzug vor 1950 */
if (EF367=9999) JZuzug=9.    /* o.A. zum Zuzugsjahr */
if (EF367=-5)   JZuzug=0.    /* kein Zuzugsjahr sinnvoll */
var lab JZuzug 'Zuzugsjahr'.
formats JZuzug (f4.0).
value label JZuzug 1949 'Zuzug vor 1950' 
                      9 'o.A. zum Zuzugsjahr'  
                      0 'kein Zuzugsjahr sinnvoll'.

if (BRDBorn=1 & JZuzug>9) Zuzug=2.
if (BRDBorn=8 & JZuzug<=9) JZuzug=9. 

* SA*: Staatsangehoerigkeit .
* nur deutsche SA .
do if (EF368=1).
   compute Ausl=0.
   compute SADopp=0.
   compute SA1=0.
   compute SA2=$sysmis.
* deutsche und auslaendische SA .
else if (EF368=2). 
   compute Ausl=0.
   compute SADopp=1.
   compute SA1=0.
   compute SA2=EF369. 
* nur auslaendische SAs .
else if (EF368=8).
   compute Ausl=1.
   compute SA1=EF369.
   if (ef370<>1) SADopp=0.
   if (ef370<>1) SA2=$sysmis.
   if (ef370=0 | ef370=-5)  SA2=0.
      if (ef370=1)  SADopp=1. 
      * DEAKTIVIERT: if (ef370=1)  SA2=ef370.
end if.

var lab SA1 'Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)'.
var lab SA2 'Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)'.
var lab SADopp 'Doppelte Staatsangehoerigkeit (EF368-EF370)'.
var lab Ausl 'Auslaendische Staatsangehoerigkeit'.
val lab Ausl SADopp 0 'nein' 1 'ja'.
formats Ausl SADopp SA1 (f1.0) SA2 (f2.0).
execute.

* EF372: AENDERUNG FRAGEBOGEN MZ 2009 vs. MZ 2008.
* MZ 2009 | MZ 2008 Value Label.
*    1         1   Deutsche Staatsangehoerigkeit durch Geburt .
*    3         2   Deutsche Staatsangehoerigkeit als Spaetaussiedler mit Einbuergerung .
*    4         3   Deutsche Staatsangehoerigkeit durch Einbuergerung .
*    2         4   Deutsche Staatsangehoerigkeit als Spaetaussiedler ohne Einbuergerung .
*   -5         0   Entfaellt (Person ohne deutsche Staatsangehoerigkeit) .

* Spaetaussiedler ohne Einbuergerung .
do if (EF372=2).
   compute SpAuss=1.
   compute Eingeb=0.
   compute JEinb=$sysmis.
   recode EF374 (-5=sysmis) (else=copy) into SA3.
   recode EF369 (-5=sysmis) (else=copy) into SA2.
* Spaetaussiedler mit Einbuergerung .
else if (EF372=3).
   compute SpAuss=1.
   compute Eingeb=1.
   recode EF373 (-5=9) (else=copy) into JEinb.
   recode EF374 (-5=sysmis) (else=copy) into SA3.
   recode EF369 (-5=sysmis) (else=copy) into SA2.
* sonstige Einbuergerung .
else if (EF372=4).
   compute SpAuss=0.
   compute Eingeb=1.
   recode EF373 (-5=9) (else=copy) into JEinb.
   recode EF374 (-5=sysmis) (else=copy) into SA3.
   recode EF369 (-5=sysmis) (else=copy) into SA2.
* Deutsch durch Geburt .
else if (EF372=1).
   compute SpAuss=0.
   compute Eingeb=0.
   compute JEinb=$sysmis.
   recode EF369 (-5=sysmis) (else=copy) into SA2.
* keine deutsche Staatsangehoerigkeit  .
else if (Ausl=1).
  compute SpAuss=0.
  compute Eingeb=0.
  compute JEinb=$sysmis.
  compute SA3=$sysmis.
end if.

var lab SpAuss 'Spaetaussiedler'.
var lab Eingeb 'Eingebuergert'.
var lab JEinb 'Einbuergerungsjahr'.
var lab SA3 'Staatsangeh. vor Einbuergerung/Zuzug als Spaetaussiedler'.
formats SpAuss Eingeb (f1.0) JEinb (f4.0) SA3 (f2.0).
val lab SpAuss Eingeb 0 'nein' 1 'ja'.
execute.

* -------------------------------------------------------------------.
* Ueberblick zu nachfolgenden Zuweisungen                            .
* MIG: Migrationstypus                                               .
*      1. Stelle: Migrationstyp:                                     .
*                 1=vertrieben                                       .
*                 2=als Deutsche/r bzw. Spaetaussiedler zugewandert  .
*                 3=eingebuergert                                    .
*                 4=Auslaender/in                                    .
*      2. Stelle: Generation:                                        .
*                 1=im Ausland geboren                               .
*                 2=in Deutschland geboren                           .
* Vorlaeufige Codes MIG                                              .
* 11=Vertriebene vor 1950                                            .
* 21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung).
* 22=Ehegatte o. Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuerg.) .
* 25=(Spaet-)Aussiedler (mit Einbuergerung)                          .
* 29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr .
* 31=zugewanderter eingebuergerter Auslaender                        .
* 32=nicht zugewanderter eingebuergerter Auslaender                  .
* 41=zugewanderter Auslaender                                        .
* 42=nicht zugewanderter Auslaender                                  .
* 77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler         .
* 99=fehlende/unvollstaendige Angaben                                .
* ----------------------------------                                 .
* SA_erw: Erweiterte aktuelle Staatsangehoerigkeit                   .
*         [Basis fuer MIGS Staatsangehoerigkeit: Migrationsstatus]   .
*         gewonnen aus                                               .
*           SA1 Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)  .
*           SA2 Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370) .
*           SA3 Staatsangeh. vor Einbuerg./Zuzug als Spaetaussiedler .
*         nach folgenden Regeln:                                     .
* SA_erw = 0   = deutsch (bei MIG=0, 11)                             .
*        = SA1 (bei Mig=41,42)                                       .
*        = SA3 (bei Mig=21,25,29,31,32 und SA3<>.)                   .
*        = SA2 (bei MIG=21,25,29,31,32 und SA3=. und SA2<>.)         .
*        = 99  (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder      .
*               bei MIG=77,99)                                       .
*          [Sysmis sind oben bezeichnet mit: "." ]                   .
* -------------------------------------------------------------------.

* A) im Ausland geboren.
* A1) als Auslaender zugewandert. 
do if (BRDBorn=8 & Ausl=1).
       compute MIG=41.
       compute SA=SA1.
       compute SA_erw=SA1.
* A2) Spaetaussiedler/in .
*     SA_erw: SA vor Einbuergerung .
*             wenn fehlt, 2. SA (Doppelstaatler) .
*             ansonsten 'missing' .
else if (BRDBorn=8 & SpAuss=1 & Eingeb=1).
       compute MIG=25.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* Spaetaussiedler ohne Einbuergerung  .
else if (BRDBorn=8 & SpAuss=1 & Eingeb=0).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* kein Spaetaussiedler ... .
* A3) Eingebuergerte/r .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=1).
       compute MIG=31.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* ... Deutsche/r durch Geburt.
* A4) Vertriebener vor 1950 .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=1949).
       compute MIG=11.
       compute SA=SA1.
       compute SA_erw=SA1.
* A5) Aussiedler-aequivalent .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug>1949).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann .
*                         Vertriebener oder Spaetaussiedler sein.
* Annahme 1: wenn nach 1949 geboren, dann als Spaetaussiedler 
*            zugewandert.
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=9 & Gebj>1949).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* SAS-Programm Grundtypisierung <=> SPSS mig = 99 => noch MIG=21 .
* select if mig=99.
* fre BRDBorn SpAuss Eingeb Jzuzug Gebj      SADopp SA1.
*     8        0      0     9      1911-1949    0    0 .	 
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=9 & Gebj>=1911 & Gebj<=1949).
       compute MIG=21.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* Annahme 2: Wenn vor 1949 geboren und keine auslaendaendische SA, .
*            dann Vertriebener .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=1949 & Gebj<=1949 & SADopp=0 & SA1=0).
       compute MIG=11.
       compute SA=SA1.
       compute SA_erw=SA1.
* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 .
else if (BRDBorn=8 & SpAuss=0 & Eingeb=0 & JZuzug=9 & Gebj<=1949 & 
         SADopp=1 & SA1=0).
       compute MIG=29.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* B) im Inland geboren: .
* B1) als Auslaender in D geboren .
else if (BRDBorn=1 & Ausl=1).
       compute MIG=42.
       compute SA=SA1.
       compute SA_erw=SA1.
* B2) Spaetaussiedler/in, Fehler! .
else if (BRDBorn=1 & SpAuss=1).
       compute MIG=77.
       compute SA=SA1. 
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* B3) Eingebuergerte/r .
else if (BRDBorn=1 & Eingeb=1).
       * MZ 2008: if (EF5b=0) MIG=32. /* SAS: Fassung fuer Jahresbestand */
       * MZ 2008: if (EF5b=1) MIG=31. /* SAS: Fassung fuer Jahresueberhang */
       compute MIG=32. /* MZ 2009: Jahresbestand und -ueberhang */
       compute SA=SA1. 
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=99.
* B4) in Deutschland geborener Deutscher .
else if (BRDBorn=1 & Ausl=0 & SpAuss=0 & Eingeb=0).
       compute MIG=77.
       compute SA=SA1. 
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=SA1.
*   BRDBorn=9: keine Auskunft; kommt wohl nicht vor .
else if (BRDBorn=9).
       compute Mig=99.
       compute SA=SA1.
       compute SA_erw=SA3.
       if (sysmis(SA_erw)) SA_erw=SA2.
       if (sysmis(SA_erw)) SA_erw=SA1.
end if.

formats BRDBorn Zuzug Ausl SADopp SpAuss Eingeb (f1.0).
formats SA SA1 SA2 SA3 SA_erw  MIG (f2.0).
formats Gebj  JZuzug JEinb (f4.0).
var lab SA 'Aktuelle Staatsangehoerigkeit'. 
var lab SA_erw 'Erweiterte aktuelle Staatsangehoerigkeit'.
var lab MIG 'Migrationsstatus'.
recode MIG (sysmis=99).
val label MIG 
    0 'SYSMIS'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.
execute.

compute sa_erw1 = sa_erw.
formats sa_erw1 (f2.0).
var lab sa_erw1 'Erw. Staatsangeh. vor Plausibilis.'.

* Zwischenspeicherung MIG vor Plausibilisierungen und vor VE/ME .
save outfile ='temp_mig1.sav'.


* -------------------------------------------------------------------.
* Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31), dann .
* pruefen, ob ggf. Spaetaussiedlerstatus vorliegt .
* a) Ehegatte ist Spaetaussiedler (MIG[Ehegatte]=21-29) .
* b) Vater ist Spaetaussiedler (MIG[Vater]=21-29) .
* c) Mutter ist Spaetaussiedler (MIG[Mutter]=21-29) .
* Nachfolgende Pruefungen der Gruppe der Zuwanderer mit Angaben zu .
* einer Einbuergerung, ob ggf. ein Spaetaussiedlerstatus vorliegt, . 
* gehen von dieser Definition valider Spaetaussiedler .
* (ex: 02Vorlauf.sas) aus:  .
*   EF366 = 8 &               (Geburtsland nicht BRD)  .
*   & (EF372 = 3 | EF372 = 2) (Besitz der deutschen Staatsangeh. 
*                              als (Spaet-)Aussiedler mit oder .
*                              ohne Einbuergerung) . 
*   & JZuzug>1949             (Zuzugsjahr nach 1949).
* -------------------------------------------------------------------.

* Der in den einzelnen Programmschritten gebildete Migrationsstatus .
*    (MIG) wird zur Kontrolle der jeweiligen Rekodierungen umbenannt.
*    Am Ende erhaelt die Typisierung wieder den Variablennamen MIG.  
rename variables (MIG = MIG1).
var label MIG1 'Migrationsstatus vor Plausibilisierung a) Ehegatte'.

* -------------------------------------------------------------------.
* A) PLAUSIBILISIERUNG - EHEGATTE .
compute VORL = (EF366=8 & (EF372=3 | EF372=2) & JZuzug>1949). 
var label VORL 'Valide Spaetaussiedler - PERSON'.
formats VORL (f1.0).

temporary.
select if (EF50=1)  /* Ehegatte im Haushalt */ .
save /outfile='temp_E.sav'
     /keep  = EF1 EF3 V4 V5 mig1 VORL JZuzug EF366 EF372 
     /rename (V5    JZuzug  EF366   EF372   mig1   VORL = 
              EF5_E JahrZ_E EF366_E EF372_E mig1_E VORL_E).
execute.

if (EF50=1) EF5_E = EF51.
var label EF5_E 'Nr. des Ehepartners im Haushalt (EF51)'.
formats EF5_E (f2.0).

* Sortierung fuer Zusammenspielen mit Angaben der Ehegatten. 
sort cases by EF1 EF3 V4 EF5_E.

* Angaben der Ehegatten zusammenspielen. 
match files file=*
           /table='temp_E.sav'
           /by EF1 EF3 V4 EF5_E.
execute.

* Sortierung des Ausgangsfiles .
sort cases by  EF1 EF3 V4 V5 .

* Pruefung und Rekodierung. 
compute MIG1a=MIG1.
if (MIG1=31       /* Wenn Zuwanderer angibt, eingebuergert zu sein */
    & JZuzug>10   /* und valides Zuzugsjahr */
    & EF50=1      /* Ehegatte im Haushalt (ergaenzt) */
    & (abs(JZuzug-JahrZ_E)<3)  /* Diff Zuzugsjahre +- 3 Jahre  */
    & VORL_E=1)   /* Ehegatte ist valider Spaetaussiedler */
    MIG1a=22.
formats MIG1a (f2.0).
var label MIG1a 'Migrationsstatus nach Plausib a) Ehegatte'.

* ----------------------------------------------------------------------------.
* B) PLAUSIBILISIERUNG - VATER .
compute vnr = EF55 * (EF54=1).
formats vnr (f2.0).
var label vnr 'Personennr. des Vaters (EF55)'.

* ==> Sortierung ... vnr.
sort cases by  EF1 EF3 V4 vnr.

temporary.
select if (vnr>0).
compute V5=vnr.
aggregate outfile='temp_V1.sav'
     /break EF1 EF3 V4 V5
     /V_Kids 'Kinder des Vaters' = n.
execute.

sort cases by  EF1 EF3 V4 V5.
* Angaben des Vaters zuspielen. 
match files file=*
           /table='temp_V1.sav'
           /by EF1 EF3 V4 V5.
execute.

recode V_Kids (1 thru hi=1) into VATER.
var label VATER 'Vater lediger Kinder im HH'.
formats VATER (f1.0).

temporary.
select if (VATER=1).
save /outfile='temp_V2.sav'
     /keep  = EF1 EF3 V4 V5 mig1a VORL JZuzug EF366 EF372 
     /rename (V5  JZuzug  EF366   EF372   mig1a   VORL = 
              vnr JahrZ_V EF366_V EF372_V mig1a_V VORL_V).
execute.

* Sortierung fuer Zusammenspielen VATER. 
sort cases by EF1 EF3 V4 vnr.

* Angaben des Vaters zuspielen. 
match files file=*
           /table='temp_V2.sav'
           /by EF1 EF3 V4 vnr.
execute.

* Sortierung des Ausgangsfiles wieder herstellen: .
sort cases by  EF1 EF3 V4 V5 .

* Pruefung und Rekodierung. 
compute MIG1b=MIG1a.
execute.
if (MIG1a=31        /* Wenn Zuwanderer angibt, eingebuergert zu sein */
    & JZuzug>10     /* und valides Zuzugsjahr */
    & EF54=1        /* Vater im Haushalt (ergaenzt) */
    & (abs(JZuzug-JahrZ_V)<3)  /* Diff Zuzugsjahre +- 3 Jahre */
    & VORL_V=1)     /* Vater ist valider Spaetaussiedler */
    MIG1b=22.
formats MIG1b (f2.0).
var label MIG1b 'Migrationsstatus nach Plausib a) Eheg. + b) Vater'.
execute.

* -------------------------------------------------------------------.
* C) PLAUSIBILISIERUNG - MUTTER .
compute mnr = EF53 * (EF52=1).
formats mnr (f2.0).
var label mnr 'Personennr. der Mutter (EF53)'.

* ==> Sortierung ... mnr.
sort cases by  EF1 EF3 V4 mnr.

temporary.
select if (mnr>0).
compute V5=mnr.
aggregate outfile='temp_M1.sav'
     /break EF1 EF3 V4 V5
     /M_Kids 'Kinder der Mutter' = n.
execute.

sort cases by  EF1 EF3 V4 V5.
* Angaben der Mutter zuspielen. 
match files file=*
           /table='temp_M1.sav'
           /by EF1 EF3 V4 V5.
execute.

recode M_Kids (1 thru hi=1) into MUTTER.
var label MUTTER 'Mutter lediger Kinder im HH'.
formats MUTTER (f1.0).

temporary.
select if (MUTTER=1).
save /outfile='temp_M2.sav'
     /keep  = EF1 EF3 V4 V5 mig1b   VORL    JZuzug  EF366 EF372 
     /rename (V5  JZuzug   EF366   EF372   mig1b   VORL = 
              mnr JahrZ_M  EF366_M EF372_M mig1b_M VORL_M).
execute.

* Sortierung fuer Zusammenspielen MUTTER. 
sort cases by EF1 EF3 V4 mnr.

* Angaben der Mutter zuspielen. 
match files file=*
           /table='temp_M2.sav'
           /by EF1 EF3 V4 mnr.
execute.

* Sortierung des Ausgangsfiles wieder herstellen: .
sort cases by  EF1 EF3 V4 V5 .

* Pruefung und Rekodierung. 
compute MIG1c=MIG1b.
execute.
if (MIG1b=31        /* Wenn Zuwanderer angibt, eingebuergert zu sein */
    & JZuzug>10     /* und valides Zuzugsjahr */
    & EF52=1        /* Mutter im Haushalt (ergaenzt) */
    & (abs(JZuzug-JahrZ_M)<3)  /* Diff Zuzugsjahre +- 3 Jahre */
    & VORL_M=1)    /* Mutter ist valider Spaetaussiedler */
    MIG1c=22.
formats MIG1c (f2.0).
var label MIG1c 'Migrationsstatus nach Plausib a), b) + c) Mutter'.
execute.

compute MIG2 = MIG1c.
formats MIG2 (f2.0).
var label MIG2 'Migrationsstatus nach Plausibilisierungen (MIG=31, a-c)'.
val label MIG2 
    0 'SYSMIS'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.
* fre mig2.
   
*   Ausgangssortierung .
sort cases by  EF1 EF3 V4 V5.

* ----------------------------------------------------------------------------.
* 1a Typisierung des Migrationshintergrundes nicht im Haushalt lebender Eltern.
*    Angaben zum Vater: Nomenklatur wie oben mit Suffix VE (Vater extern) .
*    Bearbeitung nur, wenn Vater nicht im Haushalt lebt, d.h. wenn EF357='8' .
* Vorbelegung: keine Angaben zu Vater im HH.
compute IsVE=0. 
var lab IsVE "Vater lebt im Haushalt".
val lab IsVE 0 "ja" 1 "nein (ef357=8)".
formats IsVe (f1.0).
compute ZuzugVe=$sysmis.
compute AuslVE=$sysmis.
compute AuslVE=$sysmis.
compute SADoppVE=$sysmis.
compute SA1VE=$sysmis.
compute SA2VE=$sysmis.
compute SA3VE=$sysmis. 
compute	SpAussVE=$sysmis.
compute EingebVE=$sysmis.
compute JEinbVE=$sysmis.
compute SAVE=$sysmis.
compute SA_erwVE=$sysmis.

do if (EF357=8). /* Vater lebt nicht im Haushalt */ 
+   compute IsVE=1. 
+   recode ef358 (1=1) (7 8=0) (else = sysmis) into ZuzugVE. 
+   recode ef359 (9999=9) (else=copy) (-5=sysmis) into JZuzugVE.
+   if (ZuzugVE=1 & ef360=1) AuslVE=0.        /* nur deutsche SA 
+   if (ZuzugVE=1 & ef360=1) SADoppVE=0. 
+   if (ZuzugVE=1 & ef360=1) SA1VE=0. 
+   if (ZuzugVE=1 & ef360=2) AuslVE=0.        /* deutsche und auslaendische SA 
+   if (ZuzugVE=1 & ef360=2) SADoppVE=1. 
+   if (ZuzugVE=1 & ef360=2 & ef361=-5) SA2VE=99. 
+   if (ZuzugVE=1 & ef360=2 & ef361<>-5) SA2VE=ef361. 
+   if (ZuzugVE=1 & ef360=8) AuslVE=1.        /* nur auslaendische SA oder SAs 
+   if (ZuzugVE=1 & ef360=8 & ef361=-5)  SA1VE=99. 
+   if (ZuzugVE=1 & ef360=8 & ef361<>-5) SA1VE=ef361. 
+   if (ZuzugVE=1 & ef360=8 & ef362<1)  SADoppVE = 0. /* 0 und -5 als SYSMIS behandeln */
+   if (ZuzugVE=1 & ef360=8 & ef362>0)   SADoppVE = 1.  /* DEAKTIVIERT: if (ZuzugVE=1 & ef360=8 & ef362>0) SA2VE = ef362 */ 
+   if (ZuzugVE=1 & ef360=-5) AuslVE=$sysmis. /* 'entfaellt' Auspraegung 
+   if (ZuzugVE=1 & ef360=-5) SADoppVE=$sysmis. 
+   if (ZuzugVE=1 & ef360=-5) SA1VE=$sysmis. 
+   if (ZuzugVE=1 & ef360=-5) SA2VE=$sysmis. 
+   if (ZuzugVE=1 & ef360=-5) SA3VE=$sysmis. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=2) SpAussVE=1.  /* ab hier nur noch Deutsche...  Spaetaussiedler ohne Einbuergerung */ 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=2) EingebVE=0. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=2) JEinbVE=$sysmis. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=2 & ef365<>-5) SA3VE=ef365.   /* SA vor Zuzug 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=2 & ef361<>-5) SA2VE=ef361.   /* 2. SA 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=3) SpAussVE=1. /* Spaetaussiedler mit Einbuergerung 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=3) EingebVE=1. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=3 & ef364=9999)  JEinbVE=9. /* Einbuergerungsjahr 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=3 & ef364<>9999 & ef364<>-5) JEinbVE=EF364. /* <> SAS */ 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=3 & ef365<>-5) SA3VE=ef365. /* SA vor Zuzug 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=3 & ef361<>-5) SA2VE=ef361. /* 2. SA  -5 => sysmis ? 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=4) SpAussVE=0. /* sonstige Einbuergerung 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=4) EingebVE=1. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=4 & ef364=9999)  JEinbVE=9. /* Einbuergerungsjahr 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=4 & (ef364<>9999 & ef364<>-5)) JEinbVE=EF364. /* <> SAS */ 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=4 & ef365<>-5) SA3VE=ef365.  /* SA vor Einbuergerung 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=4 & ef361<>-5) SA2VE=ef361.  /* 2. SA 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=1) SpAussVE=0. /* Deutsche durch Geburt 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=1) EingebVE=0. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=1) JEinbVE=$sysmis. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=1) SA3VE=0. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=1) SA1VE=0. 
+   if (ZuzugVE=1 & AuslVE=0 & ef363=1 & ef361<>-5) SA2VE=ef361. /* 2. SA 
+   if (ZuzugVE=1 & AuslVE=1) MIGVE=41.       /* a1) Auslaender, im Ausland geboren 
+   if (ZuzugVE=1 & AuslVE=1) SAVE=SA1VE. 
+   if (ZuzugVE=1 & AuslVE=1) SA_erwVE=SA1VE. /* SA und SA_erw: auslaendische SA 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=1) MIGVE=25. /* ... als Deutscher zugewandert A2) Spaetaussiedler/in mit Einbuergerung 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=1) SAVE=SA1VE. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=1) SA_erwVE=SA3VE. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=1 & sysmis(SA_erwVE)) SA_erwVE=SA2VE. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=1 & sysmis(SA_erwVE)) SA_erwVE=99. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=0) MIGVE=21. /* Spaetaussiedler ohne Einbuergerung 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=0) SAVE=SA1VE. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=0) SA_erwVE=SA3VE. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=0 & sysmis(SA_erwVE)) SA_erwVE=SA2VE. 
+   if (ZuzugVE=1 & AuslVE<>1 & SpAussVE=1 & EingebVE=0 & sysmis(SA_erwVE)) SA_erwVE=99. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=1) MIGVE=31. /* kein Spaetaussiedler ... A3) Eingebuergerte/r 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=1) SAVE=SA1VE. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=1) SA_erwVE=SA3VE. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=1 & sysmis(SA_erwVE)) SA_erwVE=SA2VE. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=1 & sysmis(SA_erwVE)) SA_erwVE=99. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=0) MIGVE=77.  /* Deutsch durch Geburt 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=0) SAVE=SA1VE. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=0) SA_erwVE=SA3VE. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=0 & sysmis(SA_erwVE)) SA_erwVE=SA2VE. 
+   if (ZuzugVE=1 & AuslVE=0 & SpAussVE=0 & EingebVE=0 & sysmis(SA_erwVE)) SA_erwVE=99. 
end if. 
 
do if (ZuzugVE=0). 
   compute MigVE=77. 
*   compute ZuzugVE=$sysmis.
   compute AuslVE=$sysmis. 
   compute AuslVE=$sysmis. 
   compute SpAussVE=$sysmis. 
   compute EingebVE=$sysmis. 
   compute JEinbVE=$sysmis. 
   compute SADoppVE=$sysmis. 
   compute SA1VE=0. 
   compute SAVE=SA1VE. 
   compute SA_erwVE=0. 
   if (SA3VE>=0 & SA3VE<=98) SA_erwVE=SA3VE. 
   if (SA2VE>=0 & SA2VE<=98) SA_erwVE=SA2VE. 
end if. 

do if (sysmis(ZuzugVE)). 
   compute MigVE=77. 
   compute JZuzugVE=$sysmis. 
   compute AuslVE=$sysmis. 
   compute SpAussVE=$sysmis. 
   compute EingebVE=$sysmis. 
   compute JEinbVE=$sysmis. 
   compute SADoppVE=$sysmis. 
   compute SA1VE=0. 
   compute SAVE=SA1VE. 
   compute SA_erwVE=0. 
   if (SA3VE>=0 & SA3VE<=98) SA_erwVE=SA3VE. 
   if (SA2VE>=0 & SA2VE<=98) SA_erwVE=SA2VE. 
   compute ZuzugVE=$sysmis. 
end if. 
recode ZuzugVE (1=1) (else=sysmis). 
execute. 

var lab MigVE "Migrationshintergrundes des Vaters (nicht im Haushalt lebend)". 
val lab MigVE 11 "Vertriebene vor 1950" 
              21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" 
              22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" 
              25 "(Spaet-)Aussiedler (mit Einbuergerung)" 
              29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" 
              31 "zugewanderte/r eingebuergerte/r Auslaender/in" 
              32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" 
              41 "zugewanderte/r Auslaender/in" 
              42 "nicht zugewanderte/r Auslaender/in" 
              77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler | inkl. REST" 
              99 "fehlende/unvollstaendige Angaben". 
formats MigVE (f2.0). 
 
var lab ZuzugVE "Zuzug des Vaters (ex EF358)". 
val lab ZuzugVE 1 "nach 1960 zugezogen = foreign born (EF358=1)". 
*               0 "vor 1960 oder nicht zugezogen (EF358=7,8)" => sysmis. 
*               . "k.A. (EF358=9)". 
formats ZuzugVE (f1.0). 
 
var lab AuslVE "Jahr des Zuzugs des Vaters (ex EF359)". 
val lab AuslVE 9 "k.A. zum Zuzugsjahr (EF359=9999)". 
*                1960 - 2009: jeweiliges Jahr.; 
*                   . "kein Zuzug" . 
formats AuslVE (f4.0). 
 
var lab AuslVE "Staatsangehoerigkeit des Vaters". 
val lab AuslVE  0 "deutsche Staatsangehoerigkeit (einschliesslich doppelte)" 
                     1 "nicht-deutsche Staatsangehoerigkeit". 
formats AuslVE (f1.0). 
 
var lab SpAussVE "Deutsche Staatsangehoerigkeit des Vaters als Spaetaussiedler mit/ohne Einbuergerung". 
val lab SpAussVE 1 "Spaetaussiedler". 
formats SpAussVE (f1.0). 
 
var lab EingebVE "Deutsche Staatsangehoerigkeit des Vaters durch Einbuergerung". 
val lab EingebVE 1 "Eingebuergert". 
formats EingebVE (f1.0). 
 
var lab JEinbVE "Jahr der Einbuergerung des Vaters". 
val lab JEinbVE 9 "k.A." 
               -5 "Entfaellt (Person ohne deutsche Staatsangehoerigkeit; Spaetaussiedler ohne Einbuergerung)". 
formats JEinbVE (f4.0). 
 
 
var lab SADoppVE "doppelte Staatsangehoerigkeit des Vaters". 
val lab SADoppVE 0 "keine doppelte Staatsangehoerigkeit" 
                    1 "doppelte Staatsangehoerigkeit". 
formats SADoppVE (f1.0). 
 
var lab SAVE "aktuelle Staatsangehoerigkeit des Vaters". 
formats SAVE (f2.0). 
 
var lab SA1VE "Aktuelle (erste) Staatsangehoerigkeit des Vaters". 
formats SA1VE (f2.0). 
 
var lab SA2VE "Aktuelle (zweite) Staatsangehoerigkeit des Vaters". 
formats SA2VE (f2.0). 
 
val lab SAVE SA1VE SA2VE 
             10 "4/10/11/36: Daenemark(04); Griechenland(10); Irland(11); Vereinigtes Koenigreich(36)" 
             13 "1/9/13/18/21: Belgien(01); Frankreich(09); Italien(13); Luxemburg(18); Niederlande(21)" 
             14 "Kroatien" 
             23 "3/7/15/17/19/23/25/30/31/33/35/37: Bulgarien(03); Estland(07); Lettland(15); Litauen(17); Malta(19); Polen(23); Rumaenien" 
             26 "5/26/56/90/93: Sowjetunion(05); Russische Foederation(26); Ukraine(56); Belarus(90); Republik Moldau(93)" 
             32 "8/22/24/27/32: Finnland(08); Oesterreich(22); Portugal(24); Schweden(27); Spanien(32)" 
             34 "Tuerkei" 
             57 "12/16/20/28/39/40-42/43-46/47-49/50-52/53/54/55/94-96/98: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28); Sons" 
             58 "2/6/58/59/91/92: Bosnien- und Herzegowina(02); Jugoslawien(06);Serbien(58); Montenegro(59); Kosovo(91); Mazedonien(92)". 
 
var lab SA3VE "Staatsangehoerigkeit vor Einbuergerung/Zuzug als Spaetaussiedler (EF365)". 
formats SA3VE (f2.0). 
 
var lab SA_erwVE "erweiterte aktuelle Staatsangehoerigkeit des Vaters". 
formats SA_erwVE (f2.0). 
val lab SA3Ve SA_erwVE 
              0 "deutsch bzw. unzutreffend" 
              7  "7 7/15/17/19/31/37: Estland(07); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)" 
             10 "4/8/10/11/22/24/27/32/36: Daenemark(04); Finnland(08); Griechenland(10); Irland(11); Oesterreich(22); Portugal(24); Schwed" 
             13 "1/9/13/18/21: Belgien(01); Frankreich(09); Italien(13); Luxemburg(18); Niederlande(21)" 
             14 "2/14/92: Bosnien- und Herzegowina(02); Kroatien(14); Mazedonien(92)" 
             23 "Polen" 
             25 "3/25: Bulgarien(03); Rumaenien(25)" 
             26 "Russische Foederation" 
             33 "30/33: Slowakei(30); Tschechische Republik(33)" 
             34 "Tuerkei" 
             35 "Ungarn" 
             40 "40/41: Marokko(40); Sonstiges Nordafrika (z.B. aegypten, Tunesien)(41)" 
             42 "Sonstiges Afrika" 
             48 "47/48: Irak(47); Iran(48)" 
             49 "Sonstiger Naher und Mittlerer Osten (z.B. Israel, Jordanien, Libanon, Syrien)" 
             50 "50/51: Vietnam(50); Afghanistan(51)" 
             52 "Sonstiges Sued- und Suedostasien (z.B. Indien, Indonesien, Kambodscha, Philippinen, Thailand)" 
             53 "53/54: China(53); Sonstiges Ostasien (z.B. Japan, Korea)(54)" 
             56 "Ukraine" 
             57 "Kasachstan" 
             58 "58/59/91: Serbien(58); Montenegro(59); Kosovo(91)" 
             93 "12/16/20/28/39/90/93/96: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28); Sonstiges Europa(39); Belarus(90); Re" 
             95 "94/95: Georgien, Aserbaidschan, Armenien(94); Usbekistan, Turkmenistan, Tadschikistan, Kirgisistan(95)" 
             98 "43-46/55/98: Amerika(43-46); Uebrige Welt(55); Staatenlos(98)".
 


* ----------------------------------------------------------------------------.
*       ####### Nationalitaet und Staatsangehoerigkeit der Mutter ####### .
*       Angaben zur Mutter: Nomenklatur wie oben mit Suffix ME (Mutter extern)  .
*       Bearbeitung nur, wenn Mutter nicht im Haushalt lebt, d.h. wenn EF349='8' .
* Vorbelegung: keine Angaben zur Mutter im HH.
compute IsME=0.
var lab IsME "Mutter lebt im Haushalt".
val lab IsME 0 "ja" 1 "nein (ef349=8)".
formats IsMe (f1.0).
compute ZuzugMe=$sysmis.
compute JzuzugME=$sysmis.
compute AuslME=$sysmis.
compute SADoppME=$sysmis.
compute SA1ME=$sysmis.
compute SA2ME=$sysmis.
compute SA3ME=$sysmis. 
compute	SpAussME=$sysmis.
compute EingebME=$sysmis.
compute JEinbME=$sysmis.
compute SAME=$sysmis.
compute SA_erwME=$sysmis.

do if (EF349=8). /* Mutter lebt nicht im Haushalt */ 
+   compute IsME=1. 
+   recode EF350 (1=1) (7 8=0) (else = sysmis) into ZuzugME. 
+   recode EF351 (9999=9) (else=copy) (-5=sysmis) into JZuzugME.  
+   if (ZuzugME=1 & EF352=1) AuslME=0.        /* nur deutsche SA 
+   if (ZuzugME=1 & EF352=1) SADoppME=0. 
+   if (ZuzugME=1 & EF352=1) SA1ME=0. 
+   if (ZuzugME=1 & EF352=2) AuslME=0.        /* deutsche und auslaendische SA 
+   if (ZuzugME=1 & EF352=2) SADoppME=1. 
+   if (ZuzugME=1 & EF352=2 & EF353=-5) SA2ME=99. 
+   if (ZuzugME=1 & EF352=2 & EF353<>-5) SA2ME=EF353. 
+   if (ZuzugME=1 & EF352=8) AuslME=1.        /* nur auslaendische SA oder SAs 
+   if (ZuzugME=1 & EF352=8 & EF353=-5)  SA1ME=99. 
+   if (ZuzugME=1 & EF352=8 & EF353<>-5) SA1ME=EF353. 
+   if (ZuzugME=1 & EF352=8 & EF354<1)  SADoppME = 0. /* 0 und -5 als SYSMIS behandeln */
+   if (ZuzugME=1 & EF352=8 & EF354>0)   SADoppME = 1.  /* 0 und -5 als SYSMIS behandeln */
+   if (ZuzugME=1 & EF352=8 & EF354>0)   SA2ME = EF354.  /* 0 und -5 als SYSMIS behandeln */ 
+   if (ZuzugME=1 & EF352=-5) AuslME=$sysmis. /* 'entfaellt' Auspraegung 
+   if (ZuzugME=1 & EF352=-5) SADoppME=$sysmis. 
+   if (ZuzugME=1 & EF352=-5) SA1ME=$sysmis. 
+   if (ZuzugME=1 & EF352=-5) SA2ME=$sysmis. 
+   if (ZuzugME=1 & EF352=-5) SA3ME=$sysmis. 
+   if (ZuzugME=1 & AuslME=0 & EF355=2) SpAussME=1.  /* ab hier nur noch Deutsche...  Spaetaussiedler ohne Einbuergerung */ 
+   if (ZuzugME=1 & AuslME=0 & EF355=2) EingebME=0. 
+   if (ZuzugME=1 & AuslME=0 & EF355=2) JEinbME=$sysmis. 
+   if (ZuzugME=1 & AuslME=0 & EF355=2 & EF382<>-5) SA3ME=EF382.   /* SA vor Zuzug 
+   if (ZuzugME=1 & AuslME=0 & EF355=2 & EF353<>-5) SA2ME=EF353.   /* 2. SA 
+   if (ZuzugME=1 & AuslME=0 & EF355=3) SpAussME=1. /* Spaetaussiedler mit Einbuergerung 
+   if (ZuzugME=1 & AuslME=0 & EF355=3) EingebME=1. 
+   if (ZuzugME=1 & AuslME=0 & EF355=3 & EF356=9999)  JEinbME=9. /* Einbuergerungsjahr 
+   if (ZuzugME=1 & AuslME=0 & EF355=3 & EF356<>9999 & EF356<>-5) JEinbME=EF356. /* <> SAS */ 
+   if (ZuzugME=1 & AuslME=0 & EF355=3 & EF382<>-5) SA3ME=EF382. /* SA vor Zuzug 
+   if (ZuzugME=1 & AuslME=0 & EF355=3 & EF353<>-5) SA2ME=EF353. /* 2. SA  -5 => sysmis ? 
+   if (ZuzugME=1 & AuslME=0 & EF355=4) SpAussME=0. /* sonstige Einbuergerung 
+   if (ZuzugME=1 & AuslME=0 & EF355=4) EingebME=1. 
+   if (ZuzugME=1 & AuslME=0 & EF355=4 & EF356=9999)  JEinbME=9. /* Einbuergerungsjahr 
+   if (ZuzugME=1 & AuslME=0 & EF355=4 & (EF356<>9999 & EF356<>-5)) JEinbME=EF356. /* <> SAS */
+   if (ZuzugME=1 & AuslME=0 & EF355=4 & EF382<>-5) SA3ME=EF382.  /* SA vor Einbuergerung 
+   if (ZuzugME=1 & AuslME=0 & EF355=4 & EF353<>-5) SA2ME=EF353.  /* 2. SA 
+   if (ZuzugME=1 & AuslME=0 & EF355=1) SpAussME=0. /* Deutsche durch Geburt 
+   if (ZuzugME=1 & AuslME=0 & EF355=1) EingebME=0. 
+   if (ZuzugME=1 & AuslME=0 & EF355=1) JEinbME=$sysmis. 
+   if (ZuzugME=1 & AuslME=0 & EF355=1) SA3ME=0. 
+   if (ZuzugME=1 & AuslME=0 & EF355=1) SA1ME=0. 
+   if (ZuzugME=1 & AuslME=0 & EF355=1 & EF353<>-5) SA2ME=EF353. /* 2. SA 
+   if (ZuzugME=1 & AuslME=1) MIGME=41.       /* a1) Auslaender, im Ausland geboren 
+   if (ZuzugME=1 & AuslME=1) SAME=SA1ME. 
+   if (ZuzugME=1 & AuslME=1) SA_erwME=SA1ME. /* SA und SA_erw: auslaendische SA 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=1) MIGME=25. /* ... als Deutscher zugewandert A2) Spaetaussiedler/in mit Einbuergerung 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=1) SAME=SA1ME. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=1) SA_erwME=SA3ME. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=1 & sysmis(SA_erwME)) SA_erwME=SA2ME. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=1 & sysmis(SA_erwME)) SA_erwME=99. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=0) MIGME=21. /* Spaetaussiedler ohne Einbuergerung 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=0) SAME=SA1ME. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=0) SA_erwME=SA3ME. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=0 & sysmis(SA_erwME)) SA_erwME=SA2ME. 
+   if (ZuzugME=1 & AuslME<>1 & SpAussME=1 & EingebME=0 & sysmis(SA_erwME)) SA_erwME=99. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=1) MIGME=31. /* kein Spaetaussiedler ... A3) Eingebuergerte/r 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=1) SAME=SA1ME. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=1) SA_erwME=SA3ME. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=1 & sysmis(SA_erwME)) SA_erwME=SA2ME. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=1 & sysmis(SA_erwME)) SA_erwME=99. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=0) MIGME=77.  /* Deutsch durch Geburt 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=0) SAME=SA1ME. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=0) SA_erwME=SA3ME. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=0 & sysmis(SA_erwME)) SA_erwME=SA2ME. 
+   if (ZuzugME=1 & AuslME=0 & SpAussME=0 & EingebME=0 & sysmis(SA_erwME)) SA_erwME=99. 
end if.
execute.

do if (ZuzugME=0).
   compute MigME=77.
*   compute ZuzugME=$sysmis --- unten: recode --- . 
   compute JzuzugME=$sysmis.
   compute AuslME=$sysmis.
   compute SpAussME=$sysmis.
   compute EingebME=$sysmis.
   compute JEinbME=$sysmis.
   compute SADoppME=$sysmis.
   compute SA1ME=0.
   compute SAME=SA1ME.
   compute SA_erwME=0.
   if (SA3ME>=0 & SA3ME<=98) SA_erwME=SA3ME. 
   if (SA2ME>=0 & SA2ME<=98) SA_erwME=SA2ME.
end if.
* ... Ende EF349=8 .

* Restliche Faelle: uneindeutig: im Ausland verblieben oder lebte bereits hier .
do if (sysmis(ZuzugME)).
   compute MigME=77.
*   compute ZuzugME=$sysmis --- unten: recode --- . 
   compute JzuzugME=$sysmis.
   compute AuslME=$sysmis.
   compute SpAussME=$sysmis.
   compute EingebME=$sysmis.
   compute JEinbME=$sysmis.
   compute SADoppME=$sysmis.
   compute SA1ME=0.
   compute SAME=SA1ME.
   compute SA_erwME=0.
   if (SA3ME>=0 & SA3ME<=98) SA_erwME=SA3ME. 
   if (SA2ME>=0 & SA2ME<=98) SA_erwME=SA2ME.
   compute ZuzugME=$sysmis. 
end if.

recode ZuzugME (1=1) (else=sysmis).
execute.

var lab MigME "Migrationshintergrundes der Mutter (nicht im Haushalt lebend)".
val lab MigME 11 "Vertriebene vor 1950"
              21 "Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)"
              22 "Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)"
              25 "(Spaet-)Aussiedler (mit Einbuergerung)"
              29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr"
              31 "zugewanderte/r eingebuergerte/r Auslaender/in"
              32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in"
              41 "zugewanderte/r Auslaender/in"
              42 "nicht zugewanderte/r Auslaender/in" 
              77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler | inkl. REST"
              99 "fehlende/unvollstaendige Angaben".
formats MigME (f2.0).

var lab ZuzugME "Zuzug der Mutter (ex EF350)".
val lab ZuzugME 1 "nach 1960 zugezogen = foreign born (EF350=1)".
*               0 "vor 1960 oder nicht zugezogen (EF350=7,8)" => sysmis.
*               . "k.A. (EF350=9)".
formats ZuzugME (f1.0).

var lab JzuzugME "Jahr des Zuzugs der Mutter (ex EF351)".
val lab JzuzugME 9 "k.A. zum Zuzugsjahr (EF351=9999)".
*                1960 - 2009: jeweiliges Jahr.; 
*                   . "kein Zuzug" .
formats JzuzugME (f4.0).

var lab AuslME "Staatsangehoerigkeit der Mutter".
val lab AuslME  0 "deutsche Staatsangehoerigkeit (einschliesslich doppelte)"
                      1 "nicht-deutsche Staatsangehoerigkeit".
formats AuslME (f1.0).

var lab SpAussME "Deutsche Staatsangehoerigkeit der Mutter als Spaetaussiedler mit/ohne Einbuergerung".
val lab SpAussME 1 "Spaetaussiedler".
formats SpAussME (f1.0).

var lab EingebME "Deutsche Staatsangehoerigkeit der Mutter durch Einbuergerung".
val lab EingebME 1 "Eingebuergert".
formats EingebME (f1.0).

var lab JEinbME "Jahr der Einbuergerung der Mutter".
val lab JEinbME 9 "k.A."
               -5 "Entfaellt (Person ohne deutsche Staatsangehoerigkeit; Spaetaussiedler ohne Einbuergerung)".
formats JEinbME (f4.0).

var lab SADoppME "doppelte Staatsangehoerigkeit der Mutter".
val lab SADoppME 0 "keine doppelte Staatsangehoerigkeit"
                 1 "doppelte Staatsangehoerigkeit".
formats SADoppME (f1.0).

var lab SAME "aktuelle Staatsangehoerigkeit der Mutter".
formats SAME (f2.0).

var lab SA1ME "Aktuelle (erste) Staatsangehoerigkeit der Mutter".
formats SA1ME (f2.0).

var lab SA2ME "Aktuelle (zweite) Staatsangehoerigkeit der Mutter".
formats SA2ME (f2.0).

val lab SAME SA1ME SA2ME 
             10 "4/10/11/36: Daenemark(04); Griechenland(10); Irland(11); Vereinigtes Koenigreich(36)"
             13 "1/9/13/18/21: Belgien(01); Frankreich(09); Italien(13); Luxemburg(18); Niederlande(21)"
             14 "Kroatien"
             23 "3/7/15/17/19/23/25/30/31/33/35/37: Bulgarien(03); Estland(07); Lettland(15); Litauen(17); Malta(19); Polen(23); Rumaenien"
             26 "5/26/56/90/93: Sowjetunion(05); Russische Foederation(26); Ukraine(56); Belarus(90); Republik Moldau(93)"
             32 "8/22/24/27/32: Finnland(08); Oesterreich(22); Portugal(24); Schweden(27); Spanien(32)"
             34 "Tuerkei"
             57 "12/16/20/28/39/40-42/43-46/47-49/50-52/53/54/55/94-96/98: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28); Sons"
             58 "2/6/58/59/91/92: Bosnien- und Herzegowina(02); Jugoslawien(06);Serbien(58); Montenegro(59); Kosovo(91); Mazedonien(92)".

var lab SA3ME "Staatsangehoerigkeit vor Einbuergerung/Zuzug als Spaetaussiedler (EF382)".
formats SA3ME (f2.0).

var lab SA_erwME "erweiterte aktuelle Staatsangehoerigkeit der Mutter".
formats SA_erwME (f2.0).
val lab SA3ME SA_erwME
             0 "deutsch bzw. unzutreffend"
             7  "7 7/15/17/19/31/37: Estland(07); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)"
            10 "4/8/10/11/22/24/27/32/36: Daenemark(04); Finnland(08); Griechenland(10); Irland(11); Oesterreich(22); Portugal(24); Schwed"
            13 "1/9/13/18/21: Belgien(01); Frankreich(09); Italien(13); Luxemburg(18); Niederlande(21)"
            14 "2/14/92: Bosnien- und Herzegowina(02); Kroatien(14); Mazedonien(92)"
            23 "Polen"
            25 "3/25: Bulgarien(03); Rumaenien(25)"
            26 "Russische Foederation"
            33 "30/33: Slowakei(30); Tschechische Republik(33)"
            34 "Tuerkei"
            35 "Ungarn"
            40 "40/41: Marokko(40); Sonstiges Nordafrika (z.B. Aegypten, Tunesien)(41)"
            42 "Sonstiges Afrika"
            48 "47/48: Irak(47); Iran(48)"
            49 "Sonstiger Naher und Mittlerer Osten (z.B. Israel, Jordanien, Libanon, Syrien)"
            50 "50/51: Vietnam(50); Afghanistan(51)"
            52 "Sonstiges Sued- und Suedostasien (z.B. Indien, Indonesien, Kambodscha, Philippinen, Thailand)"
            53 "53/54: China(53); Sonstiges Ostasien (z.B. Japan, Korea)(54)"
            56 "Ukraine"
            57 "Kasachstan"
            58 "58/59/91: Serbien(58); Montenegro(59); Kosovo(91)"
            93 "12/16/20/28/39/90/93/96: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28); Sonstiges Europa(39); Belarus(90); Re"
            95 "94/95: Georgien, Aserbaidschan, Armenien(94); Usbekistan, Turkmenistan, Tadschikistan, Kirgisistan(95)"
            98 "43-46/55/98: Amerika(43-46); Uebrige Welt(55); Staatenlos(98)".

compute sa_erw2 = sa_erw.
formats sa_erw2 (f2.0).
var lab sa_erw2 'Erw. Staatsangeh. nach Plausibil.'.

* Zwischenspeicherung NACH GRUNDTYPISIERUNG & PLAUSIBILISIERUNG.
save outfile ='temp_mig2.sav'.

* ====================================================================.
* 2. Identifikation von 3-Generationen-Haushalten                     .
*    Fuer die nachfolgende Typisierung des Migrationshintergrundes    .
*    von Eltern unter Verwendung von Angaben der Grosseltern werden   .
*    in diesem Schritt 3-Generationen-Haushalte identifiziert und     .
*    Identifikatoren fuer Grossmuetter- und -vaeter gebildet.         .

* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter: .
*   Personennummer der Grossmutter .
compute gmnr = ( (MUTTER=1 | VATER=1) & EF52=1) * EF53.
* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: 
*   Personennummer des Grossvaters .
compute gvnr = ( (MUTTER=1 | VATER=1) & EF54=1) * EF55. 

temporary.
* Eltern - Pers.Nr. der Grosseltern .
select if (MUTTER=1 | VATER=1).
aggregate outfile = 'temp_GE.sav'
         /presorted
         /break EF1 EF3 V4 
         /min_gmnr = min(gmnr)
         /max_gmnr = max(gmnr)
         /min_gvnr = min(gvnr)
         /max_gvnr = max(gvnr).
execute.

* Personennr. der Grosseltern zuspielen. 
match files file=*
           /table='temp_GE.sav'
           /by EF1 EF3 V4 .
formats gmnr gvnr min_gmnr max_gmnr min_gvnr max_gvnr (f2.0).
execute.

* Ausgangssortierung fuer Tests.
sort cases by  EF1 EF3 V4 V5 .

* Kontrolle: mehr als 1 Grossmutter(nummer) im HH? .
*            Voraussetzung fuer spaetere Verwendung von .
*            'max' gmnr gvnr ist, dass dies nicht zutrifft.
temporary.
select if (max_gmnr<>min_gmnr & min_gmnr>0).
crosstabs max_gmnr by min_gmnr.
* Nach Korrektur OK.

* Falls aber doch: Beispiel fuer Dateninspektion.
* temporary.
* select if ( (max_gmnr<>min_gmnr & min_gmnr>0) 
            | (max_gvnr<>min_gvnr & min_gvnr>0) ).
* list variables EF3 V4 V5 EF44 EF46 EF52 EF53 mutter gmnr max_gmnr 
               EF54 EF55 gvnr max_gvnr .
* temporary.
* select if ( (EF3=2637 & V4=1202) | (EF3=11354 & V4=2002) | (EF3=25858 & V4=704)).
* list variables EF3 EF4 V4 EF5a EF5b EF12 V5 EF44 EF46 EF52 EF53 mutter gmnr max_gmnr EF54 EF55 gvnr max_gvnr .
* KORREKTUR siehe oben.


* Kontrolle: mehr als 1 Grossvater(nummer) im HH? .
temporary.
select if (max_gvnr<>min_gvnr & min_gvnr>0).
crosstabs max_gvnr by min_gvnr.
* OK.

* Grossvater-/mutter .
compute GMutter = (max_gmnr=V5 & max_gmnr>0).
compute GVater  = (max_gvnr=V5 & max_gvnr>0).
var label GMutter 'Grossmutter mit Kindern, Enkeln im HH'.
var label GVater  'Grossvater mit Kindern, Enkeln im HH'.
* val label GMutter GVater 1 'ja'.
formats GMutter GVater (f1.0).
execute.


* ====================================================================.
* 3. Endtypisierung der Grosseltern                                   .

* ------- ZUNAECHST NUR DIE IM HAUSHALT LEBENDEN GROSSELTERN -------  .

* Sichern des Migrationsstatus vor Endtypisierung Grosseltern.
rename variables (MIG2 = MIG2a).
var label MIG2a "Migrationsstatus nach Plausibilisierungen (MIG=31, a-c), vor Endtypisierung Grosseltern". 

* Bei Grosseltern liegen nur externe Angaben (*VE, *ME) vor .
do repeat V = MIGVE SA1VE SA2VE SA3VE SAVE SA_erwVE  /* externe Angaben zum Vater */
         /M = MIGME SA1ME SA2ME SA3ME SAME SA_erwME  /* externe Angaben zur Mutter */
         /Y = MIGV  SA1V  SA2V  SA3V  SAV  SA_erwV   /* Angaben zum Vater */
         /Z = MIGM  SA1M  SA2M  SA3M  SAM  SA_erwM . /* Angaben zur Mutter */ 
* Nur fuer die als Grossvater bzw. Grossmutter gekennzeichneten Personen.
if (gvater=1 | gmutter=1) Y = V.
if (gvater=1 | gmutter=1) Z = M.
end repeat.

var lab MIGV "Migrationsstatus Vater - vorl. nur fuer Grosseltern"
       /MIGM "Migrationsstatus Mutter - vorl. nur fuer Grosseltern".
formats MIGV MIGM (f2.0).


do if (gvater = 1 | gmutter=1).
if not any (MIG2a, 11, 21, 22, 25, 29, 31, 41) KonvProc=1.
end if.
var lab KonvProc 'Konversionsprozedur: gueltige Faelle - Grosseltern'.

do if (KonvProc=1).  /* im Inland geborene GROSSELTERN */ 
    recode MIG2a (else=copy) into mig_k. /* MIG-Status vor Konversion */
    recode MIGV  (sysmis=99) (22 23=21) (else=copy) into migV_k. /* MIG-Status Vater   */
    recode MIGM  (sysmis=99) (22 23=21) (else=copy) into migM_k. /* MIG-Status Mutter  */
end if.
formats mig_k migV_k migM_k (f2.0).
execute.

* Sortierung fuer Match mit Konversionsprozedur.
sort cases by mig_k migV_k migM_k KonvProc.

*   conversion.sav ex: conversion_2011.xls .
match files file = *
            table = 'conversion.sav' 
     /by mig_k migV_k migM_k KonvProc.
execute.

* Neu bilden, da durch Match ueberschrieben.
do if (gvater = 1 | gmutter=1).
if not any (MIG2a, 11, 21, 22, 25, 29, 31, 41) KonvProc=1. 
end if.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Uebernahme konvertierter MIG-Typisierung.
if not(sysmis(migneu)) MIG2 = migneu.
if (sysmis(migneu))    MIG2 = MIG2a.
formats MIG2 (f2.0).
var label MIG2 'Migrationsstatus nach Endtypisierung Grosseltern'.
val label MIG2 
    0 'SYSMIS; Deutsch ohne Migrationshintergrund'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   43 'Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern im heutigen Bundesgebiet geboren'
   62 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.

* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag .
*        ergaenzen, sofern noetig und moeglich .
*    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern.
compute SA_erw0 = SA_erw.
do if (KonvProc=1).
   if ( (SA_erw=0 | SA_erw=99) & (SA_erwV>0 & SA_erwV<99) ) SA_erw=SA_erwV.
   if ( (SA_erw=0 | SA_erw=99) & (SA_erwM>0 & SA_erwM<99) ) SA_erw=SA_erwM.
end if.
execute.

compute sa_erw3 = sa_erw.
formats sa_erw3 (f2.0).
var lab sa_erw3 'Erw. Staatsangeh. nach Endtypis. Grosseltern'.
execute.

* Variablen aus Datei conversion.sav loeschen.
delete variables  MIG_K  MIGV_K MIGM_K Konvproc MIGNEU KENNUNG .
execute.

* ====================================================================.
* 4. Endtypisierung der Eltern                                        .
*      Fuer jede Kombination von eigenem, vaeterlichen und            .
*      muetterlichen vorlaeufigen Migrationsstatus wird der           .
*      resultierende endgueltige Migrationsstatus zugewiesen. Diese   .
*      Konversions-Prozedur wird nur fuer im Inland Geborene angewandt.
*      Abschliessend wird die Variable erweiterte Staatsangehoerigkeit.
*      (SA_erw) ggf. durch Informationen zum Vater bzw. zur Mutter    .
*      ergaenzt.                                                      .

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* ===== ANGABEN ZU DEM IM HAUSHALT LEBENDEN GROSSVATER ===== .
* Angaben zum Migrationsstatus des Grossvaters speichern.
temporary.
select if (GVater=1).
save outfile = 'temp_GV.sav'
         /keep EF3 V4 V5 MIG2   SA1    SA2    SA3    SA    SA_erw  
         /rename (V5     MIG2   SA1    SA2    SA3    SA    SA_erw = 
                  gvnr   MIG_GV SA1_GV SA2_GV SA3_GV SA_GV SAerw_GV).
execute.

* Sortierung fuer Zusammenspielen Eltern- mit Grossvater-Angaben.
sort cases by EF1 EF3 V4 gvnr.

* Angaben der (Gross-) Vaeter zuspielen. 
match files file=*
           /table='temp_GV.sav'
           /by EF3 V4 gvnr.
execute.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Angaben zum Status des Grossvaters nur falls der Grossvater .
*   der Vater ist, sonst SYSMIS.
do if (gvnr<>EF55).
 recode MIG_GV SA1_GV SA2_GV SA3_GV SA_GV SAerw_GV (else=sysmis).
end if.
formats MIG_GV SA1_GV SA2_GV SA3_GV SA_GV SAerw_GV (f2.0).
execute.


* ===== ANGABEN ZU DER IM HAUSHALT LEBENDEN GROSSMUTTER ===== .
* Angaben zum Migrationsstatus der Grossmutter speichern.
temporary.
select if (GMutter=1).
save outfile = 'temp_GM.sav'
         /keep EF3 V4   V5 MIG2 SA1 SA2 SA3 SA SA_erw  
         /rename (V5   MIG2   SA1    SA2    SA3    SA    SA_erw = 
                  gmnr MIG_GM SA1_GM SA2_GM SA3_GM SA_GM SAerw_GM).
execute.

* Sortierung fuer Zusammenspielen Eltern- mit Grossmutter-Angaben.
sort cases by EF1 EF3 V4 gmnr.

* Angaben der (Gross-) Muetter zuspielen. 
match files file=*
           /table='temp_GM.sav'
           /by EF3 V4 gmnr.
execute.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Angaben zum Status der Grossmutter nur falls die Grossmutter .
*   die Mutter ist, sonst SYSMIS.
do if (gmnr<>EF53).
   recode MIG_GM SA1_GM SA2_GM SA3_GM SA_GM SAerw_GM (else=sysmis).
end if.
formats MIG_GM SA1_GM SA2_GM SA3_GM SA_GM SAerw_GM (f2.0).
execute.


* --- NUN AUCH DATEN ZU DEN NICHT IM HAUSHALT LEBENDEN GROSSELTERN ---          .

*       Zusammenfuehren der Angaben zu Grosseltern in und ausserhalb des Haushalts .
*       Bei Grosseltern liegen nur externe Angaben vor                           .
* ELTERN MIT GROSSELTERN IM HH                   ANGABEN ZU GROSSELTERN         .
*  VATER=1  & (GVNR=EF55): Vater mit Grossvater   MIG_GV, ..., SAerw_GV [VATER] .
*  VATER=1  & (GMNR=EF53): Vater mit Grossmutter  MIG_GM, ..., SAerw_GM [MUTTER].
*  MUTTER=1 & (GVNR=EF55): Mutter mit Grossvater  MIG_GV, ..., SAerw_GV [VATER] .
*  MUTTER=1 & (GMNR=EF53): Mutter mit Grossmutter MIG_GM, ..., SAerw_GM [MUTTER].

* -------------------------------------------------------------------------.
* Ab hier die eigentliche Endtypisierung des Migrationsstatus der .
*    Eltern mittels Konversions-Prozedur, bei der nur im Inland   .
*    Geborene beruecksichigt werden                               .
if not any (MIG2, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.
var lab KonvProc 'Konversionsprozedur: gueltige Faelle'.

if ( (VATER=1  & (GVNR=EF55)) | /* Vater mit Grossvater */
     (VATER=1  & (GMNR=EF53)) | /* Vater mit Grossmutter */
     (MUTTER=1 & (GVNR=EF55)) | /* Mutter mit Grossvater */
     (MUTTER=1 & (GMNR=EF53)))  /* Mutter mit Grossmutter */
    EGRE=1.
var lab EGRE 'Eltern mit Grosseltern im Haushalt'.
formats Konvproc EGRE (f1.0).
execute.

* Typisierung Eltern-Grosseltern.
compute EGRETYP=0.
if (VATER=1  & GVNR=EF55)             EGRETYP=1.  /* Vater mit Grossvater */ 
if (VATER=1  & GMNR=EF53)             EGRETYP=2.  /* Vater mit Grossmutter */
if (VATER=1  & GVNR=EF55 & GMNR=EF53) EGRETYP=3.  /* Vater mit Grossvater und -mutter */
if (MUTTER=1 & GVNR=EF55)             EGRETYP=4.  /* Mutter mit Grossvater */
if (MUTTER=1 & GMNR=EF53)             EGRETYP=5.  /* Mutter mit Grossmutter */
if (MUTTER=1 & GVNR=EF55 & GMNR=EF53) EGRETYP=6.  /* Mutter mit Grossvater und -mutter */
var lab EGRETYP 'Eltern mit Grosseltern im Haushalt'.
val lab EGRETYP 0 'TNZ'
                1 'Vater mit Grossvater'
                2 'Vater mit Grossmutter'
                3 'Vater mit Grosseltern'
                4 'Mutter mit Grossvater'
                5 'Mutter mit Grossmutter'
                6 'Mutter mit Grosseltern'.
formats EGRETYP (f1.0).

do if (KonvProc=1 & (VATER=1 | MUTTER=1)). /* Nur im Inland geborene Eltern */
   recode MIG2   (else=copy) into mig_k.   /* MIG-Status Eltern vor Konversion */
   if (IsVE=1)    migV_k = MIGVE.   /* Vater lebt nicht im HH  (EF357=8) */ 
   if (IsME=1)    migM_k = MIGME.   /* Mutter lebt nicht im HH (EF349=8) */
   if (EGRETYP=1) migV_k = MIG_GV.  /* Vater mit Grossvater im HH */ 
   if (EGRETYP=2) migM_k = MIG_GM.  /* Vater mit Grossmutter */
   if (EGRETYP=3) migV_k = MIG_GV.  /* Vater mit Grossvater und -mutter */
   if (EGRETYP=3) migM_k = MIG_GM.  /* Vater mit Grossvater und -mutter */
   if (EGRETYP=4) migV_k = MIG_GV.  /* Mutter mit Grossvater */
   if (EGRETYP=5) migM_k = MIG_GM.  /* Mutter mit Grossmutter */
   if (EGRETYP=6) migV_k = MIG_GV.  /* Mutter mit Grossvater und -mutter */ 
   if (EGRETYP=6) migM_k = MIG_GM.  /* Mutter mit Grossvater und -mutter */ 
   recode migM_k migV_k (sysmis=99) (else=copy).
end if.
formats mig_k migV_k migM_k (f2.0).
execute.

* Staatsangehoerigkeit erweitert (SA_erw) der Eltern (die nicht Grosseltern sind).
do if ( (VATER=1  & (GVATER=0  | sysmis(GVATER))) | 
        (MUTTER=1 & (GMUTTER=0 | sysmis(GMUTTER))) ).
*   compute SA_erwV=99.
*   compute SA_erwM=99.
   if (IsVE=1)    SA_erwV=SA_erwVE.   /* Vater lebt nicht im HH  (EF357=8) */ 
   if (IsME=1)    SA_erwM=SA_erwME.   /* Mutter lebt nicht im HH (EF349=8) */
   if (EGRETYP=1) SA_erwV=SAerw_GV.   /* Vater mit Grossvater im HH */ 
   if (EGRETYP=2) SA_erwM=SAerw_GM.   /* Vater mit Grossmutter */
   if (EGRETYP=3) SA_erwV=SAerw_GV.   /* Vater mit Grossvater und -mutter */
   if (EGRETYP=3) SA_erwM=SAerw_GM.   /* Vater mit Grossvater und -mutter */
   if (EGRETYP=4) SA_erwV=SAerw_GV.   /* Mutter mit Grossvater */
   if (EGRETYP=5) SA_erwM=SAerw_GM.   /* Mutter mit Grossmutter */
   if (EGRETYP=6) SA_erwV=SAerw_GV.   /* Mutter mit Grossvater und -mutter */ 
   if (EGRETYP=6) SA_erwM=SAerw_GM.   /* Mutter mit Grossvater und -mutter */ 
   recode SA_erwV SA_erwM (sysmis=99) (else=copy).
end if.
formats SA_erwV SA_erwM (f2.0).
execute.

* Sortierung fuer Match mit Konversionsprozedur.
sort cases by mig_k migV_k migM_k KonvProc.

* ------------------------------------------------------ .
* Datei conversion.sav enthaelt die Variablen: .
*  MIG_K  Migrationsstatus der Person (hier: Vater) (SAS: _mig_).
*  MIGV_K Migrationsstatus des Vaters (hier: Grossvater) (SAS: _migv_).
*  MIGM_K Migrationsstatus der Mutter (hier: Grossmutter) (SAS: _migm_).
*  Konvproc (Konstante: 1) Hilfsvariable fuer Match.
*  MIGNEU Migrationsstatus nach Konversion (Rekodierung).
*  KENNUNG Nr. der Konversion (Rekodierung).
*  --- Beispiele Rekodierung (conversion.sav) ---.
*  MIG_K  MIGV_K  MIGM_K MIGNEU .
*    42     32      42     43   . 
*    77     21      11     52   .
*    77     21      21     62   .
* ------------------------------.
* MIG-Codes: .
*  11 'Vertriebene vor 1950' .
*  21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne 
*      Einbuergerung)' .
*  42 'Als Auslaender im heutigen Bundesgebiet geboren, entweder beide 
*      Eltern als Auslaender zugewandert oder der eine Elternteil' .
*  43 'Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern 
*      im heutigen Bundesgebiet geboren' .
*  32 'Als Auslaender im heutigen Bundesgebiet geboren und 
*      zwischenzeitlich eingebuergert' .
*  52 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus
*      durchweg identifizierbar, weil mit Eltern im Haushalt'.
*  62 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus
*      durchweg identifizierbar, weil mit Eltern im Haushalt'.
*  77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler' .
* ---------------------------------------------------------------.
match files file = *
            table = 'conversion.sav' 
     /by mig_k migV_k migM_k KonvProc.

* Neu bilden, da durch Match ueberschrieben.
if not any (MIG2, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Uebernahme konvertierter MIG-Typisierung.
if not(sysmis(migneu)) MIG3 = migneu.
if (sysmis(migneu))    MIG3 = MIG2.
formats MIG3 (f2.0).
var label MIG3 'Migrationsstatus nach Endtypisierung Eltern'.
val label MIG3
    0 'nicht zuordenbar (Rest)'
   11 'Vertriebene vor 1950'
   21 'Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)'
   22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)'
   25 '(Spaet-)Aussiedler (mit Einbuergerung)'
   29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
   31 'zugewanderte/r eingebuergerte/r Auslaender/in'
   32 'nicht zugewanderte/r eingebuergerte/r Auslaender/in'
   41 'zugewanderte/r Auslaender/in'
   42 'nicht zugewanderte/r Auslaender/in'
   77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'
   99 'fehlende/unvollstaendige Angaben'.
execute.

* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag .
*        ergaenzen, sofern noetig und moeglich .
*    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern.
compute SA_erw0 = SA_erw.
* Nur im Inland geborene Eltern (ohne Grosseltern).
*     if not any (MIG2, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1. 
do if (KonvProc=1 & 
      ( (VATER=1  & (GVATER=0  | sysmis(GVATER)) ) | 
        (MUTTER=1 & (GMUTTER=0 | sysmis(GMUTTER))) ) ).
   if ( (SA_erw=0 | SA_erw=99) & (SA_erwV>0 & SA_erwV<99) ) SA_erw=SA_erwV.
   if ( (SA_erw=0 | SA_erw=99) & (SA_erwM>0 & SA_erwM<99) ) SA_erw=SA_erwM.
end if.
execute.

compute sa_erw4 = sa_erw.
formats sa_erw4 (f2.0).
var lab sa_erw4 'Erw. Staatsangeh. zu MIG3 - nach Endtypis. der Eltern'.

* Ausgangssortierung .
sort cases by  EF1 EF3 V4 V5 .

* Zwischenspeicherung MIG nach Endtypisierung der Eltern.
save outfile = 'temp_mig3.sav' /drop = sa_erw0.

* fre mig3 sa_erw.


* ====================================================================.
* 5. Endtypisierung Befragte                                          .
*       Analog zur Endtypisierung der Eltern wird der endgueltige     .
*       Migrationsstatus unter Beruecksichtigung der Kombinationen    .
*       von eigenem, vaeterlichen und muetterlichen vorlaeufigen      .
*       Migrationsstatus zugewiesen, wobei auch hier die Zuweisungen  .
*       nur fuer die im Inland Geborenen zur Anwendung kommen, und    .
*       die erweiterte Staatsangehoerigkeit (SA_erw) ggf. durch       .
*       Angaben des Vaters bzw. der Mutter ergaenzt wird.             .
*       Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum    .
*       Migrationsstatus (MIGS).                                      .

* UMBENENNEN der oben gebildeten Variablen, die sonst ueberschrieben werden.
* MIGV Migrationsstatus Vater - vorl. nur fuer Grosseltern  .
* MIGM Migrationsstatus Mutter - vorl. nur fuer Grosseltern .
rename variables (MIGV = MIGV_GE) (MIGM = MIGM_GE).

* Ausgangssortierung.
sort cases by EF1 EF3 V4 V5.

* === ZUNAECHST ANGABEN DER IM HAUSHALT LEBENDEN ELTERN  === .

* Migrationsrelevante Eintraege fuer Vaeter speichern .
*    MIG  SA1 SA2 SA3 SA SA_erw JZuzug.
temporary.
select if (Vater=1).
save outfile = 'temp_V.sav'
     /keep EF3 V4 V5  MIG3  SA1   SA2    SA3    SA    SA_erw   JZuzug 
         /rename (V5  MIG3  SA1   SA2    SA3    SA    SA_erw   JZuzug = 
                  vnr MIG_V SA1_V SA2_V  SA3_V  SA_V  SA_erw_V JZuzug_V).
execute.

* Sortierung fuer Zusammenspielen Befragten- mit Vaeterangaben.
sort cases by EF1 EF3 V4 vnr.

* Angaben der Vaeter zuspielen. 
match files file=*
           /table='temp_V.sav'
           /by EF3 V4 vnr.
execute.

* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* ---------------------------------------------------------------- .
* Migrationsrelevante Eintraege fuer Muetter speichern .
*    MIG SA1 SA2 SA3 SA SA_erw JZuzug.
temporary.
select if (Mutter=1).
save outfile = 'temp_M.sav'
     /keep EF3 V4 V5  MIG3  SA1   SA2   SA3   SA   SA_erw   JZuzug 
         /rename (V5  MIG3  SA1   SA2   SA3   SA   SA_erw   JZuzug = 
                  mnr MIG_M SA1_M SA2_M SA3_M SA_M SA_erw_M JZuzug_M).
execute.

* Sortieren fuer Zusammenspielen Befragten- mit Muetterangaben.
sort cases by EF1 EF3 V4 mnr.

* Angaben der Muetter zuspielen. 
match files file=*
           /table='temp_M.sav'
           /by EF3 V4 mnr.
execute.
* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* Vorher zugespielte Variablen aus conversion.sav loeschen.
delete variables mig_k migV_k migM_k Konvproc migneu kennung.   


* Konversions-Prozedur nur fuer im Inland Geborene .
if not any (MIG3, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.
execute.

* === BERUECKSICHTIGUNG VON ANGABEN DER NICHT IM HAUSHALT LEBENDEN ELTERN  === .

* Vorbereitung MATCH Konversionstabelle (conversion.sav) .
* [08-Endtypisierung Befragte normale Jahre.sas (MZ 2008) .

* ANGABEN ZU DEN IM HH LEBENDEN ELTERN (s.o.): .	
* Zum Vater:  MIG_V SA1_V SA2_V  SA3_V  SA_V  SA_erw_V  JZuzug_V  .
* Zur Mutter: MIG_M SA1_M SA2_M  SA3_M  SA_M  SA_erw_M  JZuzug_M  .

* Kombination Angaben zu Eltern.
* PE: EXTERN.
compute PE = (ISVE=0 & ISME=0).  /* keine externen Angaben zu den Eltern  */
if (ISVE=1 & ISME=1) PE = 2.     /* externe Angaben zu beiden Eltern      */
if (ISVE=1 & ISME=0) PE = 3.     /* externe Angaben nur zum Vater         */
if (ISVE=0 & ISME=1) PE = 4.     /* externe Angaben nur zur Mutter        */
formats PE (f1.0).
var lab PE "Externe Angaben zu den Eltern".
val lab PE 1 "keine"
           2 "beide"
           3 "Vater"
           4 "Mutter".

* PI: INTERN.
compute PI = (EF55<1 & EF53<1).  /* keine internen Angaben zu den Eltern  */
if (EF55>0 & EF53>0) PI = 2.     /* interne Angaben zu beiden Eltern      */
if (EF55>0 & EF53<1) PI = 3.     /* interne Angaben nur zum Vater         */
if (EF55<1 & EF53>0) PI = 4.     /* interne Angaben nur zur Mutter        */
formats PI (f1.0).
var lab PI "Interne Angaben zu den Eltern".
val lab PI 1 "keine"
           2 "beide"
           3 "Vater"
           4 "Mutter".

* SA_erwV und SA_erwM aus Schritt Endtypisierung Eltern sichern.
compute SA_erwV1 = SA_erwV.
compute SA_erwM1 = SA_erwM.
var lab SA_erwV1 'Erw. Staatsangeh. Vater - Endtypis. Eltern'.
var lab SA_erwM1 'Erw. Staatsangeh. Mutter - Endtypis. Eltern'.
formats SA_erwV1 SA_erwM1 (f2.0).
execute.

* Initialisierung SA_erwV und SA_erwM.
compute SA_erwV=99.
compute SA_erwM=99.
formats SA_erwV SA_erwM (f2.0).

do if (IsVE=1). /* Vater lebt nicht im HH (ef357=8) */
   compute MIGV=MIGVE.
   compute SA1V=SA1VE.
   compute SA2V=SA2VE.
   compute SA3V=SA3VE.
   compute JZuzugV=JZuzugVE.
   compute SAV=SAVE.
   compute SA_erwV=SA_erwVE.
end if.

do if (not(sysmis(MIG_V))). /* Gueltige Angaben zu dem im HH lebenden Vater */
   compute MIGV=MIG_V.
   compute SA1V=SA1_V.
   compute SA2V=SA2_V.
   compute SA3V=SA3_V.
   compute JZuzugV=JZuzug_V.
   compute SAV=SA_V.
   compute SA_erwV=SA_erw_V.
end if.

do if (IsME=1). /* Mutter lebt nicht im HH (ef349=8) */
   compute MIGM=MIGME.
   compute SA1M=SA1ME.
   compute SA2M=SA2ME.
   compute SA3M=SA3ME.
   compute JZuzugM=JzuzugME.
   compute SAM=SAME.
   compute SA_erwM=SA_erwME.
end if.

do if (not(sysmis(MIG_M))). /* Gueltige Angaben zu der im HH lebenden Mutter */
   compute MIGM=MIG_M.
   compute SA1M=SA1_M.
   compute SA2M=SA2_M.
   compute SA3M=SA3_M.
   compute JZuzugM=JZuzug_M.
   compute SAM=SA_M.
   compute SA_erwM=SA_erw_M.
end if.
execute.

* Vorbereitung MATCH Konversionstabelle (conversion.sav) .
do if (KonvProc=1).
    recode MIG3  (else=copy) into mig_k.        /* MIG-Status Person vor Konvers. */
    recode MIGV  (0=99) (sysmis=99) (22 23=21) (else=copy) into migV_k. /* Vater  */
    recode MIGM  (0=99) (sysmis=99) (22 23=21) (else=copy) into migM_k. /* Mutter */
end if.
formats mig_k migV_k migM_k (f2.0).
execute.


* Sortierung fuer Match mit Konversionsprozedur.
sort cases by mig_k migV_k migM_k KonvProc.

match files file = *
            table = 'conversion.sav' 
     /by mig_k migV_k migM_k KonvProc.


* Ausgangssortierung.
sort cases by  EF1 EF3 V4 V5.

* neu bilden, da durch Match ggf. ueberschrieben.
if not any (MIG3, 11, 21, 22, 23, 25, 29, 31, 41) KonvProc=1.
execute.


* Migrationsstatus NACH Konversion zuweisen.
if not(sysmis(migneu)) MIG4 = migneu.
if (sysmis(migneu))    MIG4 = MIG3.

var label MIG4 'Migrationsstatus nach Endtypisierung Befragte'.
formats MIG4 (f2.0).
fre MIG4.

* SUF Value Labels & Vergroeberung.
val label MIG4
   0 'Deutsch ohne Migrationshintergrund'
  11 'Bis einschliesslich 1949 als Deutscher ohne Einbuergerung ' 
   + 'auf das heutige Bundesgebiet zugewandert'
  21 '21/29: 1950 und spaeter als Deutscher ohne Einbuergerung '
   + 'auf das heutige Bundesgebiet zugewandert(Spaetaussiedler) (21) '
   + '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr (29)'
  22 'Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist'
  25 'Spaetaussiedler mit formaler Einbuergerung'
  29 '(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr'
  31 'Als Auslaender auf das heutige Bundesgebiet zugewandert '
   + 'und zwischenzeitlich eingebuergert'
  32 'Als Auslaender im heutigen Bundesgebiet geboren und '
   + 'zwischenzeitlich eingebuergert'
  41 'Als Auslaender auf das heutige Bundesgebiet zuwandert'
  42 'Als Auslaender im heutigen Bundesgebiet geboren, entweder '
   + 'beide Eltern als Auslaender zugewandert oder der eine Elternteil'
  43 'Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern '
   + 'im heutigen Bundesgebiet geboren'
  52 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  53 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  54 'Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  62 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  63 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  64 'Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus '
   + 'durchweg identifizierbar, weil mit Eltern im Haushalt'
  77 'uneindeutig ob deutsch, vertrieben oder Spaetaussiedler'.
formats mig4 (f2.0).
formats migv migm (f2.0).
execute.

* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag .
*        ergaenzen, sofern noetig und moeglich .
*    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern.
compute SA_erw0 = SA_erw.
do if (KonvProc=1).
   if ( (SA_erw=0 | SA_erw=99) & (SA_erwV>0 & SA_erwV<99) ) SA_erw=SA_erwV.
   if ( (SA_erw=0 | SA_erw=99) & (SA_erwM>0 & SA_erwM<99) ) SA_erw=SA_erwM.
end if.
execute.

* fre sa_erw.

* Zwischenspeicherung . 
save outfile = 'temp_MIG4.sav'.


* =====================================================================.
* 6. Umsetzung von Zeitreihenkompatibilitaet                           .
* In den Jahren 2005 und 2009 laesst sich aufgrund der Zusatzangaben    .
* zum Migrationsstatus der nicht im Haushalt lebenden Eltern der       .
* Migrationshintergrund von mehr Menschen erkennen als in den anderen  .
* Jahren. Das schraenkt die Zeitreihenanalyse ein.                      .
* Deshalb wird nachstehend der Migrationsstatus der Menschen in 2005/  .
* 2009 simuliert, der sich ergeben haette, wenn lediglich die Angaben   .
* aus den anderen Jahren zur Verfuegung gestanden haetten.               .
* Betroffen sind lediglich die Deutschen mit einseitigen und           .
* beidseitigem Migrationshintergrund Codes 61 bzw. 62-64               .
* Es gelten folgede Regeln:                                            .
* Einseitiger MigH: Angaben zum bestimmenden Elternteil fehlen:        .
*    Code: 52 -> 72                                                    .
*    Code: 53 -> 73                                                    .
*    Code: 54 -> 74                                                    .
* Beidseitiger MigH: Angaben zu einem bestimmenden Elternteil fehlen:  .
*    Code: 62 -> 57                                                    .
*    Code: 63 -> 58                                                    .
*    Code: 64 -> 59                                                    .
* Beidseitiger MigH: Angaben zu beiden bestimmenden Elternteilen fehlen.
*    Code: 62 -> 77                                                    .
*    Code: 63 -> 78                                                    .
*    Code: 64 -> 79                                                    .
* (...)                                                                .
* ---------------------------------------------------------------------.

* Jahrgangsspezifische Recodierung MIG2009 und MIGS2009 .
compute mig2009 = mig4.
var label mig2009 'Migrationsstatus jahrgangsspezifisch'.

compute migs2009 = sa_erw.
* Beachte: EF2008 ist aufgrund von Vergroeberungen nicht bzw. nur .
*          eingeschraenkt replizierbar .
var label migs2009 'Erweiterte Staatsangehoerigkeit zu MIGS2009 jahrgangsspezifisch [~EF2008~]'.
formats mig2009 migs2009 (f2.0).
* MIGS2009 (ex SA_erw) fuer einheimische Bevoelkerung auf Entfaellt setzen => SUF MZ 2009 EF2008: -5.
if (MIG2009=0 | MIG2009=11) MIGS2009=-5.
recode MIGS2009 (0=-5) (else=copy).


* ---------------------------------------------------------------------.
* Die Variablen xxxV werden aus den entspechenden Angaben von xxxVE und.
* xxxVI bestimmt. Wenn ISVE=1 (Es liegen Angaben zum Vater ausserhalb   .
* des Haushaltes vor) gelten die Werte von xxxVE, ansonsten die von    .
* xxxVI.                                                               .
* Werden jedoch Angaben zum Vater ausserhalb des Haushalts gemacht,     .
* obwohl dieser im Haushalt lebt, dann ueberschreiben die Angaben des   .
* Haushaltsmitglieds die externen Angaben.                             .
* Vorgehensweise bei xxxM entsprechend.                                .
* ALTERNATIVE RECODIERUNG zu SAS-Originalprogramm                      .
* Zur Umsetzung der zeitreihenkompatiblen MIG - Variable               .
* werden folgende Variablen verwendet:                                 .
* MIG4  Migrationsstatus vor Zeitreihenkompatibilitaet.                 .
* PI    Interne Angaben zu den Eltern: 1=keine, 2=beide, 3=Vater, 4=Mutter. 
* PE    Externe Angaben zu den Eltern: 1=keine, 2=beide, 3=Vater, 4=Mutter. 
* IsVE  Vater lebt im Haushalt:  0=ja, 1=nein (EF357=8) : Ext. Ang. Vater.
* IsME  Mutter lebt im Haushalt: 0=ja, 1=nein (EF357=8) : Ext. Ang. Mutter.
* MIGMI Migrationsstatus Mutter: interne Angaben.
* MIGVI Migrationsstatus Vater:  interne Angaben.
compute MIGVI = MIG_V. /* interne Angaben fuer Vater */
compute MIGMI = MIG_M. /* interne Angaben fuer Mtter */
formats MIGVI MIGMI (f2.0).
*       Hilfsvariablen (SYSMIS => -1).
recode MIGMI MIGVI (sysmis=-1) (else=copy) into xMIGMI xMIGVI.

* Zeitreihenkompatible Recodierung .
compute MIG  = MIG4.
var lab MIG 'Migrationsstatus zeitreihenkompatibel [EF2001]'.
compute MIGS = SA_erw.
var lab MIGS 'Erweiterte Staatsangehoerigkeit zu MIGS [~EF2008~]'.
* Beachte: EF2008 ist aufgrund von Vergroeberungen nicht bzw. nur .
*          eingeschraenkt replizierbar .
formats xMIGMI xMIGVI MIG MIGS (f2.0).

* Fall 1: Beidseitiger MigH der Person (mig4>=62 & mig4<=64).
*         Angaben zu beiden bestimmenden Elternteilen fehlen (PI=1).
do if ((mig4>=62 & mig4<=64) & (PI=1)).
   compute mig  = mig4+15.
   compute migs = 99.
end if.

* Fall 2: Interne Angaben fuer Mutter vorhanden (PI=4).
*         ... dann einseitiger Migrationshintergrund .
do if ((mig4>=62 & mig4<=64) & (PI=4) & (xMIGMI>=0  & xMIGMI<=77)).
   compute mig  = 58.
   compute migs = 99.
end if.
do if ((mig4>=62 & mig4<=64) & (PI=4) & (xMIGMI>=21 & xMIGMI<=29)).
   compute mig  = 57.
   compute migs = 99.
end if.
do if ((mig4>=62 & mig4<=64) & (PI=4) & (xMIGMI>=41 & xMIGMI<=43)).
   compute mig  = 59.
   compute migs = 99.
end if.

* Fall 3: Interne Angaben fuer Vater vorhanden (PI=3) und .
*         keine internen Angaben fuer Mutter vorhanden  .
*         ... dann einseitiger Migrationshintergrund .
do if ((mig4>=62 & mig4<=64) & (PI=3) & (xMIGVI>=0  & xMIGVI<=77)).
   compute mig  = 58.
   compute migs = 99.
end if.
do if ((mig4>=62 & mig4<=64) & (PI=3) & (xMIGVI>=21 & xMIGVI<=29)).
   compute mig  = 57.
   compute migs = 99.
end if.
do if ((mig4>=62 & mig4<=64) & (PI=3) & (xMIGVI>=41 & xMIGVI<=43)).
   compute mig  = 59.
   compute migs = 99.
end if.

* Fall 4: Einseitiger Migrationshintergrund (mig4>=52 & mig4<=54).
*         Externe Angaben zum Vater (ISVE=1) ohne .
*         interne Angaben zum Vater (EF55<1) ... dann Code 52-54 -> 72-74. 
do if ( (mig4>=52 & mig4<=54) & ISVE=1 & EF55<1 & 
         (any (migv, 21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) ).
   compute mig  = mig4+20.
   compute migs = 99.
end if.

* Fall 5: Einseitiger Migrationshintergrund (mig4>=52 & mig4<=54).
*         Externe Angaben zur Mutter (ISME=1) ohne
*         interne Angaben zur Mutter (EF53<1)... dann Code 52-54 -> 72-74.
do if ( (mig4>=52 & mig4<=54) & ISME=1 & EF53<1 &
         (any (migm, 21,22,23,25,29,31,32,33,41,42,43,61,62,63,64)) ).
   compute mig  = mig4+20.
   compute migs = 99.
end if.
execute.

* Hilfsvariablen loeschen.
delete variables = xMIGMI xMIGVI.

* Vergroeberungen, Rekodierungen MIGS wie EF2008 im SUF MZ 2009.
* MIGS (ex SA_erw) fuer einheimische Bevoelkerung auf Entfaellt setzen => SUF MZ 2009 EF2008: -5.
if (MIG=0 | MIG=11) MIGS=-5.
recode migs (0 = -5) (else=copy). 

val lab MIG 
   0 "Deutsch ohne Migrationshintergrund"
  11 "Bis einschl. 1949 als Deutscher ohne Einbuergerung zugewandert"
  21 "21/29: >=1950 als Deutscher ohne Einbuergerung zugewandert" 
     + "(Spaetaussiedler)(21); Ohne Angabe des Zuzugsjahres als"
     + "Deutscher ohne Einbuergerung zugewandert(29)"
  22 "Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist"
  25 "Spaetaussiedler mit formaler Einbuergerung"
  29 "Ohne Angabe des Zuzugsjahres als Deutscher ohne Einbuergerung zugewandert"
  31 "Als Auslaender zugewandert und zwischenzeitlich eingebuergert"
  32 "Als Auslaender im Bundesgebiet geboren und zwischenzeitlich eingebuergert"
  41 "Als Auslaender auf das heutige Bundesgebiet zuwandert"
  42 "Als Auslaender im Bundesgebiet geboren, beide Eltern als Auslaender"
     + " zugewandert oder ein Elternteil als Auslaender zugewandert,"
     + " der andere als Auslaender im Bundesgebiet geboren"
  43 "Als Auslaender im Bundesgeb. geboren, beide Eltern im Bundesgeb. geboren"
  52 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, "
     + "weil Eltern im Haushalt; 1 Elternteil Spaetaussiedler (21,22,25,29)"
  53 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil "
     + "mit Eltern im Haushalt; 1 Elternteil Deutscher durch Einbuerg. (31,32)"
  54 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil "
     + "mit Eltern im Haushalt; 1 Elternteil ist Auslaender (41,42,43)"
  57 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Mig-hintergrund "
     + "nicht durchweg identifizierbar, weil nur mit 1 Elternteil im "
     + "Haushalt; dieser Elternteil ist Spaetaussiedler (21,22,25,29)"
  58 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Mig-hintergrund nicht"
     + " durchweg identifizierbar, weil Betroffener nur mit 1 Elternteil im "
     + "Haushalt; dieser Elternteil ist eingebuergert (31,32)"
  59 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Mig-hintergrund "
     + "nicht durchweg identifizierbar, weil Betroffener nur mit 1 Elternteil "
     + "im Haushalt; dieser Elternteil ist Auslaender (41,42,43)"
  62 "Deutscher mit beids. Mig-hintergrund; Mig-status durchweg identifizierb.,"
     + "weil Eltern im Haushalt lebend; mind. 1 Elternteil ist "
     + "Spaetaussiedler (21,22,25,29)"
  63 "Deutscher mit beids. Mig-hintergrund; Mig-status durchweg identifizierb.,"
     + " weil Eltern im Haushalt; entweder beide Eltern eingeb. (31,32) oder "
     + " 1 Elternteil eingebuergert (31,32), der andere Auslaender (41,42,43)"
  64 "Deutscher mit beids. Mig.hintergrund; Mig-status durchweg identifizierb.,"
     + " weil Eltern im Haushalt; beide Eltern sind Auslaender (41,42,43), es "
     + "handelt sich um ein ius soli-Kind (Optionsmodell)"
  72 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Mig-status nicht "
     + "durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, "
     + "der als Spaetaussiedler (21,22,25,29) f. d. Mig-status bestimmend"
  73 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Status nicht durchweg "
     + "identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als "
     + "Deutscher durch Einbuergerung (31,32) fuer Status bestimmend ist"
  74 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Status nicht durchweg "
     + "identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als "
     + "Auslaender (41,42,43) fuer den Status bestimmend ist"
  77 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Status nicht durchweg"
     + " identifizierbar, weil mit keinem Elternteil im Haushalt; mindestens "
     + "ein Elternteil ist Spaetaussiedler (21,22,25,29)"
  78 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Status nicht durchweg"
     + " identifizierbar, weil mit keinem Elternteil im Haushalt; entweder "
     + "beide Eltern eingebuergert (31,32) oder 1 Elternteil eingebuergert "
     + "(31,32), der andere Auslaender (41,42,43)"
  79 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Status nicht durchweg"
     + " identifizierbar, weil mit keinem Elternteil im Haushalt; beide Eltern"
     + " sind Auslaender (41,42,43); ius soli-Kind (Optionsmodell)".

* ============================================================================.
* ZU BEACHTEN: MIGS stimmt nicht vollstaendig mit EF2008 ueberein, da die     .
* Codierungen der Angaben zu den Staatsangehoerigkeiten der Eltern ausserhalb .
* des Haushalts:                                                              .
* - EF353  F105a 1. ausl. Staatsangehoerigk.: Mutter                           .
* - EF361  F111a 1. ausl. Staatsangehoerigk.: Vater                            .
* von den Angaben zur Person:                                                 .
* - EF369  F99a 1. Staatsangehoerigkeit                                        .
* abweichen und die Codierungen von EF369 und EF2008 verschieden sind.        .
* ============================================================================.
* val lab MIGS 
    0 '[nicht zugeordenbar - Rest]'
    1 "1/18: Belgien(01); Luxemburg(18)"
    2 Bosnien und Herzegowina"
    3 "Bulgarien"
    4 "4/8/27: Daenemark(4); Finnland(8); Schweden(27)"
    5 "Sowjetunion"
    6 "Jugoslawien"
    9 "Frankreich"
   10 "Griechenland"
   13 "Italien"
   14 "Kroatien
   21 "Niederlande"
   22 "Oesterreich"
   23 "Polen"
   24 "Portugal"
   25 "Rumaenien"
   26 "Russische Foederation"
   28 "12/16/20/28: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28)"
   31 "7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)"
   32 "Spanien"
   33 "30/33: Slowakei(30); Tschechische Republik(33)"
   34 "Tuerkei"
   35 "Ungarn"
   36 "11/36: Irland(11); Vereinigtes Koenigreich(36)"
   40 "Marokko"
   41 "Sonstiges Nordafrika"
   42 "Sonstiges Afrika"
   43 "Vereinigte Staaten von Amerika"
   45 "44/45: Sonstiges Nordamerika [Kanada](44); Mittelamerika und Karibik(45)"
   46 "Suedamerika"
   47 "Irak"
   48 "Iran"
   49 "Sonstiger Naher und Mittlerer Osten (ohne Iran)"
   50 "Vietnam"
   51 "Afghanistan"
   52 "Sonstiges Sued- und Suedostasien"
   53 "China"
   54 "Sonstiges Ostasien"
   55 "Uebrige Welt"
   56 "Ukraine"
   57 "Kasachstan"
   58 "58/59: Serbien(58); Montenegro(59)"
   91 "Kosovo"
   92 "Mazedonien"
   94 "Georgien, Aserbaidschan, Armenien"
   95 "Usbekistan, Turkmenistan, Tadschikistan, Kirgisistan"
   96 "39/90/93/96: Sonstiges Europa(39); Belarus(90); Republik Moldau(93); Albanien(96)"
   98 "Staatenlos"
   99 "Migrationsstatus nicht bestimmbar"
   -5 "Entfaellt (Personen ohne Migrationshintergrund)" .
* fre MIG MIGS.

**************************** .
* ENDE DER MIG-TYPISIERUNG * .
**************************** .


* Kontrolle MIG = EF2001 ? .
temporary.
select if (ef2001<>mig).
crosstabs ef2001 by mig.
* OK: keine Differenzen bis auf EF2001=43 <=> MIG=42: n = 266.
*     Grund: neue Konversionstabelle (conversion_2011.xls => conversion.sav).  

* Kontrolle MIGS = EF2008 ?.
temporary.
compute diff = (ef2008<>MIGS).
formats diff (f1.0).
fre diff.
* 3.324 Differenzen; Grund: unterschiedliche Codierungen (s. o.) .


* =====================================================================.

* Randverteilungen, ohne Selektion, ohne Hochrechnung.
fre mig mig2009.

* Bevoelkerung am Hauptwohnsitz, Hochrechnung (Jahresdurchschnitt).
temporary.
select if (EF30>=1 & EF30<=2).
weight by EF952.
fre mig mig2009.


* ===================================================================.

* 7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse .

* MZ-GRUNDPROGRAMM: Migrationsstatus .
* Fachserie 1, Reihe 2.2, Tabelle 2, S. 60.
* Definition Z* entspricht Lfd. Nr. in Tab. 2.
recode MIG  (0 thru 79=1) (else=sysmis) into Z001.
recode MIG  (0 11=1) (else=sysmis) into Z002.
recode MIG  (21 thru 79=1) (else=sysmis) into Z003.
recode MIG  (72 thru 79=1) (else=sysmis) into Z004.
recode MIG  (21 thru 64=1) (else=sysmis) into Z005.
recode MIG  (21 22 25 29 31 41=1) (else=sysmis) into Z036.
recode MIG  (41=1) (else=sysmis) into Z066.
recode MIG  (21 22 25 29 31=1) (else=sysmis) into Z095.
recode MIG  (21 22 25 29=1) (else=sysmis) into Z096.
recode MIG  (31=1) (else=sysmis) into Z109.
recode MIG  (32, 42 thru 43, 52 thru 64=1) (else=sysmis) int Z133.
recode MIG  (42 43 =1) (else=sysmis) into Z140.
recode MIG  (32, 52 thru 64=1) (else=sysmis) into Z147.
recode MIG  (32=1) (else=sysmis) into Z148.
recode MIG  (52 thru 64=1 ) (else=sysmis) into Z154.
recode MIG  (62 63 64=1 ) (else=sysmis) into Z155.
recode MIG  (52 thru 59=1 ) (else=sysmis) into Z156.
var lab Z001 'Bevoelkerung insgesamt'.
var lab Z002 'Person ohne Migrationshintergrund'.
var lab Z003 'Person mit Migrationshintergrund i. w. S.'.
var lab Z004 ' darunter: Migrationshintergrund nicht durchgaengig bestimmbar'.
var lab Z005 'Personen mit Migrationshintergrund im engeren Sinn'.
var lab Z036 'Bevoelkerung mit Migrationshintergrund und eigener Migrationserfahrung'.
var lab Z066 ' Auslaender '.
var lab Z095 ' Deutsche '.
var lab Z096 ' (Spaet-) Aussiedler'.
var lab Z109 ' durch Einbuergerung'.
var lab Z133 'Personen ohne eigene Migrationserfahrung'.
var lab Z140 ' Auslaender '.
var lab Z147 ' Deutsche'.
var lab Z148 ' durch Einbuergerung '.
var lab Z154 ' mit mindestens einem zugewanderten oder als Auslaender in Deutschland geborenen Elternteil'.
var lab Z155 ' mit beidseitigem Migrationshintergrund'.
var lab Z156 ' mit einseitigem Migrationshintergrund'.
temporary.
* Bevoelkerung am Hauptwohnsitz.
select if (EF30>=1 & EF30<=2).
weight by EF952.
descriptives variables = Z001 to Z156 /statistics sum.



* STAATSANGEHOERIGKEITEN Vergleich mit Tab. 2 Fachserie 1, Reihe 2.2 .
* Recodierung Erw. Staatsangeh. (EF2008 ~  MIGS_R): 
*   Deutsche 
*   bis einschl. 1949 als D zugewandert, 
*   Deutsche Zuwanderer ohne Einbuergerung,
*   in DE geborene D mit ein-/beids. Mig-hintergund
* => 0 (deutsch) .
compute MIGS_R = EF2008.
if (MIG<20 | MIG>60) MIGS_R = 0.
* aequivalent:  if (EF2001<20 | EF2001>60) MIGS_R = 0.
var label migs_r 'Staatsangeh.: erw. Migrationsstatus - EF2008 recodiert'.
formats migs_r (f2.0).
execute.

* Z:= Lfd.Nr. in Tab. 2, Fachserie 1 R 2.2 .
recode migs_r (1 thru 6 9 10 13 14 21 thru 26 28 31 thru 36 56 58 91 92 96=1) (else=sysmis) into Z06. /* Europa */
recode migs_r (1 3 4 9 10 13 21 thru 25 31 thru 33 35 36=1) (else=sysmis) into Z07. /* EU-27 */
recode migs_r (10=1) (else=sysmis) into Z08. /* Griechenland
recode migs_r (13=1) (else=sysmis) into Z09. /* Italien */
recode migs_r (23=1) (else=sysmis) into Z10. /* Polen */
recode migs_r (25=1) (else=sysmis) into Z11. /* Rumaenien */
recode migs_r (2 5 6 14 26 28 34 56 58 91 92 96=1) (else=sysmis) into Z12. /* Sonstiges Europa */
recode migs_r (2=1) (else=sysmis) into Z13.  /* Bosnien-Herzegowina */
recode migs_r (14=1) (else=sysmis) into Z14. /* Kroatien */
recode migs_r (26=1) (else=sysmis) into Z15. /* Russische Foederation */
* recode migs_r (58=1) (else=sysmis) into Z16 --- 58: Serbien(58) & Montenegro(59) zusammengefasst.
recode migs_r (34=1) (else=sysmis) into Z17. /* Tuerkei */
recode migs_r (56=1) (else=sysmis) into Z18. /* Ukraine */
recode migs_r (40 41 42=1) (else=sysmis) into Z19. /* Afrika */
recode migs_r (43 thru 46=1) (else=sysmis) into Z20. /* Amerika */
recode migs_r (47 thru 54 57 94 95=1) (else=sysmis) into Z22. /* Asien, Australien und Ozeanien */
recode migs_r (47 thru 49 57 94 95=1) (else=sysmis) into Z23. /* Naher und Mittlerer Osten */
recode migs_r (57=1) (else=sysmis) into Z24. /* Kasachstan */
recode migs_r (50 51 52=1) (else=sysmis) into Z25. /* Sued- Suedostasien */
recode migs_r (-5 0 55 98 99=1) (else=sysmis) into Z26. /* Ohne Angabe bzw. unzutreffend */
recode migs_r (2 6 14 58 59 91 92=1) (else=sysmis) into Z27. /* Gebiet des ehemaligen Jugoslawien */
recode migs_r (5 7 15 17 26 56 57 90 93 94 95=1) (else=sysmis) into Z28. /* Gebiet der ehemaligen Sowjetunion */
var label Z06 'Europa'.
var label Z07 'EU-27'.
var label Z08 'Griechenland'.
var label Z09 'Italien'.
var label Z10 'Polen'.
var label Z11 'Rumaenien'.
var label Z12 'Sonstiges Europa'.
var label Z13 'Bosnien-Herzegowina'.
var label Z14 'Kroatien'.
var label Z15 'Russische Foederation'.
* var label Z16 'Serbien(58) & Montenegro(59)'.
var label Z17 'Tuerkei'.
var label Z18 'Ukraine'.
var label Z19 'Afrika'.
var label Z20 'Amerika'.
var label Z22 'Asien, Australien und Ozeanien'.
var label Z23 'Naher und Mittlerer Osten'.
var label Z24 'Kasachstan'.
var label Z25 'Sued- Suedostasien'.
var label Z26 'Ohne Angabe bzw. unzutreffend'.
var label Z27 'Gebiet des ehemaligen Jugoslawien'.
var label Z28 'Gebiet der ehemaligen Sowjetunion'.

temporary.
* Bevoelkerung am Hauptwohnsitz, Personen mit Mig-hintergr. im engeren Sinn.
select if (EF30>=1 & EF30<=2 & MIG>=21 & MIG<=64). /* Z005  */
weight by EF952.
descriptives variables = Z005 Z06 to Z28 /statistics sum.



* Sortierung nach Ordnungsnummern fuer Zuspielen der erstellten .
* Variablen MIG und MIG2009 zum Scientific Use File .
sort cases by EF1 EF3 EF4 EF5b EF12 EF5a.

* Zwischenspeicherung.
save outfile = 'temp_mig5.sav'.


* ################################################################################.
* PROGRAMMENDE .
